"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Webhook = exports.Event = void 0;
const request_wrapper_1 = require("../request_wrapper");
const model_1 = require("./model");
const chargebee_1 = require("../chargebee");
const result_1 = require("../result");
const util_1 = require("../util");
class Event extends model_1.Model {
    get content() {
        return new result_1.Result(this.values['content']);
    }
    set content(content) { }
    static deserialize(json) {
        let webhook_data;
        try {
            webhook_data = JSON.parse(json);
        }
        catch (Error) {
            throw ("Invalid webhook object to deserialize. " + Error.message);
        }
        let api_version = webhook_data['api_version'];
        if (util_1.Util.isNotUndefinedNEmpty(api_version) && api_version.toUpperCase() !== chargebee_1.ChargeBee._api_version.toUpperCase()) {
            throw ("API version " + "[" + api_version.toUpperCase() + "] in response does not match with client library API version [" + chargebee_1.ChargeBee._api_version.toUpperCase() + "]");
        }
        let event_result = new result_1.Result({ 'event': webhook_data });
        return event_result.event;
    }
    // OPERATIONS
    //-----------
    static list(params) {
        return new request_wrapper_1.RequestWrapper([params], {
            'methodName': 'list',
            'httpMethod': 'GET',
            'urlPrefix': '/events',
            'urlSuffix': null,
            'hasIdInUrl': false,
            'isListReq': true,
            'subDomain': null,
            'isOperationNeedsJsonInput': false,
            'jsonKeys': {}
        }, chargebee_1.ChargeBee._env);
    }
    static retrieve(event_id, params) {
        return new request_wrapper_1.RequestWrapper([event_id, params], {
            'methodName': 'retrieve',
            'httpMethod': 'GET',
            'urlPrefix': '/events',
            'urlSuffix': null,
            'hasIdInUrl': true,
            'isListReq': false,
            'subDomain': null,
            'isOperationNeedsJsonInput': false,
            'jsonKeys': {}
        }, chargebee_1.ChargeBee._env);
    }
} // ~Event
exports.Event = Event;
class Webhook extends model_1.Model {
} // ~Webhook
exports.Webhook = Webhook;
