import { RequestWrapper } from "../request_wrapper";
import { Model } from "./model";
import { filter } from "../filter";
import { ProcessWait } from "../process_wait";
export declare class Export extends Model {
    id: string;
    operation_type: string;
    mime_type: string;
    status: string;
    created_at: number;
    download?: Download;
    static wait_for_export_completion(exportId: string): ProcessWait;
    static retrieve(export_id: string, params?: any): RequestWrapper;
    static revenue_recognition(params?: _export.revenue_recognition_params): RequestWrapper;
    static deferred_revenue(params?: _export.deferred_revenue_params): RequestWrapper;
    static plans(params?: _export.plans_params): RequestWrapper;
    static addons(params?: _export.addons_params): RequestWrapper;
    static coupons(params?: _export.coupons_params): RequestWrapper;
    static customers(params?: _export.customers_params): RequestWrapper;
    static subscriptions(params?: _export.subscriptions_params): RequestWrapper;
    static invoices(params?: _export.invoices_params): RequestWrapper;
    static credit_notes(params?: _export.credit_notes_params): RequestWrapper;
    static transactions(params?: _export.transactions_params): RequestWrapper;
    static orders(params?: _export.orders_params): RequestWrapper;
    static item_families(params?: _export.item_families_params): RequestWrapper;
    static items(params?: _export.items_params): RequestWrapper;
    static item_prices(params?: _export.item_prices_params): RequestWrapper;
    static attached_items(params?: _export.attached_items_params): RequestWrapper;
    static differential_prices(params?: _export.differential_prices_params): RequestWrapper;
    static price_variants(params?: _export.price_variants_params): RequestWrapper;
}
export declare class Download extends Model {
    download_url: string;
    valid_till: number;
    mime_type?: string;
}
export declare namespace _export {
    interface revenue_recognition_params {
        report_by: string;
        currency_code?: string;
        report_from_month: number;
        report_from_year: number;
        report_to_month: number;
        report_to_year: number;
        include_discounts?: boolean;
        payment_owner?: filter._string;
        item_id?: filter._string;
        item_price_id?: filter._string;
        cancel_reason_code?: filter._string;
        business_entity_id?: filter._string;
        invoice?: invoice_revenue_recognition_params;
        subscription?: subscription_revenue_recognition_params;
        customer?: customer_revenue_recognition_params;
        relationship?: relationship_revenue_recognition_params;
    }
    interface deferred_revenue_params {
        report_by: string;
        currency_code?: string;
        report_from_month: number;
        report_from_year: number;
        report_to_month: number;
        report_to_year: number;
        include_discounts?: boolean;
        payment_owner?: filter._string;
        item_id?: filter._string;
        item_price_id?: filter._string;
        cancel_reason_code?: filter._string;
        business_entity_id?: filter._string;
        invoice?: invoice_deferred_revenue_params;
        subscription?: subscription_deferred_revenue_params;
        customer?: customer_deferred_revenue_params;
        relationship?: relationship_deferred_revenue_params;
    }
    interface plans_params {
        currency_code?: filter._string;
        plan?: plan_plans_params;
    }
    interface addons_params {
        currency_code?: filter._string;
        addon?: addon_addons_params;
    }
    interface coupons_params {
        currency_code?: filter._string;
        coupon?: coupon_coupons_params;
    }
    interface customers_params {
        export_type?: string;
        business_entity_id?: filter._string;
        customer?: customer_customers_params;
        relationship?: relationship_customers_params;
    }
    interface subscriptions_params {
        export_type?: string;
        item_id?: filter._string;
        item_price_id?: filter._string;
        cancel_reason_code?: filter._string;
        subscription?: subscription_subscriptions_params;
    }
    interface invoices_params {
        payment_owner?: filter._string;
        invoice?: invoice_invoices_params;
    }
    interface credit_notes_params {
        credit_note?: credit_note_credit_notes_params;
    }
    interface transactions_params {
        transaction?: transaction_transactions_params;
    }
    interface orders_params {
        total?: filter._number;
        order?: order_orders_params;
    }
    interface item_families_params {
        business_entity_id?: filter._string;
        include_site_level_resources?: filter._boolean;
        item_family?: item_family_item_families_params;
    }
    interface items_params {
        business_entity_id?: filter._string;
        include_site_level_resources?: filter._boolean;
        item?: item_items_params;
    }
    interface item_prices_params {
        item_family_id?: filter._string;
        item_type?: filter._enum;
        currency_code?: filter._string;
        business_entity_id?: filter._string;
        include_site_level_resources?: filter._boolean;
        item_price?: item_price_item_prices_params;
    }
    interface attached_items_params {
        item_type?: filter._enum;
        attached_item?: attached_item_attached_items_params;
    }
    interface differential_prices_params {
        differential_price?: differential_price_differential_prices_params;
        item_id?: filter._string;
    }
    interface price_variants_params {
        business_entity_id?: filter._string;
        include_site_level_resources?: filter._boolean;
        price_variant?: price_variant_price_variants_params;
    }
    interface invoice_revenue_recognition_params {
        id?: filter._string;
    }
    interface invoice_revenue_recognition_params {
        recurring?: filter._boolean;
    }
    interface invoice_revenue_recognition_params {
        status?: filter._enum;
    }
    interface invoice_revenue_recognition_params {
        price_type?: filter._enum;
    }
    interface invoice_revenue_recognition_params {
        date?: filter._timestamp;
    }
    interface invoice_revenue_recognition_params {
        paid_at?: filter._timestamp;
    }
    interface invoice_revenue_recognition_params {
        total?: filter._number;
    }
    interface invoice_revenue_recognition_params {
        amount_paid?: filter._number;
    }
    interface invoice_revenue_recognition_params {
        amount_adjusted?: filter._number;
    }
    interface invoice_revenue_recognition_params {
        credits_applied?: filter._number;
    }
    interface invoice_revenue_recognition_params {
        amount_due?: filter._number;
    }
    interface invoice_revenue_recognition_params {
        dunning_status?: filter._enum;
    }
    interface invoice_revenue_recognition_params {
        updated_at?: filter._timestamp;
    }
    interface invoice_revenue_recognition_params {
        channel?: filter._enum;
    }
    interface subscription_revenue_recognition_params {
        id?: filter._string;
    }
    interface subscription_revenue_recognition_params {
        customer_id?: filter._string;
    }
    interface subscription_revenue_recognition_params {
        status?: filter._enum;
    }
    interface subscription_revenue_recognition_params {
        cancel_reason?: filter._enum;
    }
    interface subscription_revenue_recognition_params {
        remaining_billing_cycles?: filter._number;
    }
    interface subscription_revenue_recognition_params {
        created_at?: filter._timestamp;
    }
    interface subscription_revenue_recognition_params {
        activated_at?: filter._timestamp;
    }
    interface subscription_revenue_recognition_params {
        next_billing_at?: filter._timestamp;
    }
    interface subscription_revenue_recognition_params {
        cancelled_at?: filter._timestamp;
    }
    interface subscription_revenue_recognition_params {
        has_scheduled_changes?: filter._boolean;
    }
    interface subscription_revenue_recognition_params {
        updated_at?: filter._timestamp;
    }
    interface subscription_revenue_recognition_params {
        offline_payment_method?: filter._enum;
    }
    interface subscription_revenue_recognition_params {
        auto_close_invoices?: filter._boolean;
    }
    interface subscription_revenue_recognition_params {
        channel?: filter._enum;
    }
    interface subscription_revenue_recognition_params {
        plan_id?: filter._string;
    }
    interface customer_revenue_recognition_params {
        id?: filter._string;
    }
    interface customer_revenue_recognition_params {
        first_name?: filter._string;
    }
    interface customer_revenue_recognition_params {
        last_name?: filter._string;
    }
    interface customer_revenue_recognition_params {
        email?: filter._string;
    }
    interface customer_revenue_recognition_params {
        company?: filter._string;
    }
    interface customer_revenue_recognition_params {
        phone?: filter._string;
    }
    interface customer_revenue_recognition_params {
        auto_collection?: filter._enum;
    }
    interface customer_revenue_recognition_params {
        taxability?: filter._enum;
    }
    interface customer_revenue_recognition_params {
        created_at?: filter._timestamp;
    }
    interface customer_revenue_recognition_params {
        updated_at?: filter._timestamp;
    }
    interface customer_revenue_recognition_params {
        offline_payment_method?: filter._enum;
    }
    interface customer_revenue_recognition_params {
        auto_close_invoices?: filter._boolean;
    }
    interface customer_revenue_recognition_params {
        channel?: filter._enum;
    }
    interface relationship_revenue_recognition_params {
        parent_id?: filter._string;
    }
    interface relationship_revenue_recognition_params {
        payment_owner_id?: filter._string;
    }
    interface relationship_revenue_recognition_params {
        invoice_owner_id?: filter._string;
    }
    interface invoice_deferred_revenue_params {
        id?: filter._string;
    }
    interface invoice_deferred_revenue_params {
        recurring?: filter._boolean;
    }
    interface invoice_deferred_revenue_params {
        status?: filter._enum;
    }
    interface invoice_deferred_revenue_params {
        price_type?: filter._enum;
    }
    interface invoice_deferred_revenue_params {
        date?: filter._timestamp;
    }
    interface invoice_deferred_revenue_params {
        paid_at?: filter._timestamp;
    }
    interface invoice_deferred_revenue_params {
        total?: filter._number;
    }
    interface invoice_deferred_revenue_params {
        amount_paid?: filter._number;
    }
    interface invoice_deferred_revenue_params {
        amount_adjusted?: filter._number;
    }
    interface invoice_deferred_revenue_params {
        credits_applied?: filter._number;
    }
    interface invoice_deferred_revenue_params {
        amount_due?: filter._number;
    }
    interface invoice_deferred_revenue_params {
        dunning_status?: filter._enum;
    }
    interface invoice_deferred_revenue_params {
        updated_at?: filter._timestamp;
    }
    interface invoice_deferred_revenue_params {
        channel?: filter._enum;
    }
    interface subscription_deferred_revenue_params {
        id?: filter._string;
    }
    interface subscription_deferred_revenue_params {
        customer_id?: filter._string;
    }
    interface subscription_deferred_revenue_params {
        status?: filter._enum;
    }
    interface subscription_deferred_revenue_params {
        cancel_reason?: filter._enum;
    }
    interface subscription_deferred_revenue_params {
        remaining_billing_cycles?: filter._number;
    }
    interface subscription_deferred_revenue_params {
        created_at?: filter._timestamp;
    }
    interface subscription_deferred_revenue_params {
        activated_at?: filter._timestamp;
    }
    interface subscription_deferred_revenue_params {
        next_billing_at?: filter._timestamp;
    }
    interface subscription_deferred_revenue_params {
        cancelled_at?: filter._timestamp;
    }
    interface subscription_deferred_revenue_params {
        has_scheduled_changes?: filter._boolean;
    }
    interface subscription_deferred_revenue_params {
        updated_at?: filter._timestamp;
    }
    interface subscription_deferred_revenue_params {
        offline_payment_method?: filter._enum;
    }
    interface subscription_deferred_revenue_params {
        auto_close_invoices?: filter._boolean;
    }
    interface subscription_deferred_revenue_params {
        channel?: filter._enum;
    }
    interface subscription_deferred_revenue_params {
        plan_id?: filter._string;
    }
    interface customer_deferred_revenue_params {
        id?: filter._string;
    }
    interface customer_deferred_revenue_params {
        first_name?: filter._string;
    }
    interface customer_deferred_revenue_params {
        last_name?: filter._string;
    }
    interface customer_deferred_revenue_params {
        email?: filter._string;
    }
    interface customer_deferred_revenue_params {
        company?: filter._string;
    }
    interface customer_deferred_revenue_params {
        phone?: filter._string;
    }
    interface customer_deferred_revenue_params {
        auto_collection?: filter._enum;
    }
    interface customer_deferred_revenue_params {
        taxability?: filter._enum;
    }
    interface customer_deferred_revenue_params {
        created_at?: filter._timestamp;
    }
    interface customer_deferred_revenue_params {
        updated_at?: filter._timestamp;
    }
    interface customer_deferred_revenue_params {
        offline_payment_method?: filter._enum;
    }
    interface customer_deferred_revenue_params {
        auto_close_invoices?: filter._boolean;
    }
    interface customer_deferred_revenue_params {
        channel?: filter._enum;
    }
    interface relationship_deferred_revenue_params {
        parent_id?: filter._string;
    }
    interface relationship_deferred_revenue_params {
        payment_owner_id?: filter._string;
    }
    interface relationship_deferred_revenue_params {
        invoice_owner_id?: filter._string;
    }
    interface plan_plans_params {
        id?: filter._string;
    }
    interface plan_plans_params {
        name?: filter._string;
    }
    interface plan_plans_params {
        price?: filter._number;
    }
    interface plan_plans_params {
        period?: filter._number;
    }
    interface plan_plans_params {
        period_unit?: filter._enum;
    }
    interface plan_plans_params {
        trial_period?: filter._number;
    }
    interface plan_plans_params {
        trial_period_unit?: filter._enum;
    }
    interface plan_plans_params {
        addon_applicability?: filter._enum;
    }
    interface plan_plans_params {
        giftable?: filter._boolean;
    }
    interface plan_plans_params {
        status?: filter._enum;
    }
    interface plan_plans_params {
        updated_at?: filter._timestamp;
    }
    interface plan_plans_params {
        channel?: filter._enum;
    }
    interface addon_addons_params {
        id?: filter._string;
    }
    interface addon_addons_params {
        name?: filter._string;
    }
    interface addon_addons_params {
        charge_type?: filter._enum;
    }
    interface addon_addons_params {
        price?: filter._number;
    }
    interface addon_addons_params {
        period?: filter._number;
    }
    interface addon_addons_params {
        period_unit?: filter._enum;
    }
    interface addon_addons_params {
        status?: filter._enum;
    }
    interface addon_addons_params {
        updated_at?: filter._timestamp;
    }
    interface addon_addons_params {
        channel?: filter._enum;
    }
    interface coupon_coupons_params {
        id?: filter._string;
    }
    interface coupon_coupons_params {
        name?: filter._string;
    }
    interface coupon_coupons_params {
        discount_type?: filter._enum;
    }
    interface coupon_coupons_params {
        duration_type?: filter._enum;
    }
    interface coupon_coupons_params {
        status?: filter._enum;
    }
    interface coupon_coupons_params {
        apply_on?: filter._enum;
    }
    interface coupon_coupons_params {
        created_at?: filter._timestamp;
    }
    interface coupon_coupons_params {
        updated_at?: filter._timestamp;
    }
    interface customer_customers_params {
        id?: filter._string;
    }
    interface customer_customers_params {
        first_name?: filter._string;
    }
    interface customer_customers_params {
        last_name?: filter._string;
    }
    interface customer_customers_params {
        email?: filter._string;
    }
    interface customer_customers_params {
        company?: filter._string;
    }
    interface customer_customers_params {
        phone?: filter._string;
    }
    interface customer_customers_params {
        auto_collection?: filter._enum;
    }
    interface customer_customers_params {
        taxability?: filter._enum;
    }
    interface customer_customers_params {
        created_at?: filter._timestamp;
    }
    interface customer_customers_params {
        updated_at?: filter._timestamp;
    }
    interface customer_customers_params {
        offline_payment_method?: filter._enum;
    }
    interface customer_customers_params {
        auto_close_invoices?: filter._boolean;
    }
    interface customer_customers_params {
        channel?: filter._enum;
    }
    interface relationship_customers_params {
        parent_id?: filter._string;
    }
    interface relationship_customers_params {
        payment_owner_id?: filter._string;
    }
    interface relationship_customers_params {
        invoice_owner_id?: filter._string;
    }
    interface subscription_subscriptions_params {
        id?: filter._string;
    }
    interface subscription_subscriptions_params {
        customer_id?: filter._string;
    }
    interface subscription_subscriptions_params {
        status?: filter._enum;
    }
    interface subscription_subscriptions_params {
        cancel_reason?: filter._enum;
    }
    interface subscription_subscriptions_params {
        remaining_billing_cycles?: filter._number;
    }
    interface subscription_subscriptions_params {
        created_at?: filter._timestamp;
    }
    interface subscription_subscriptions_params {
        activated_at?: filter._timestamp;
    }
    interface subscription_subscriptions_params {
        next_billing_at?: filter._timestamp;
    }
    interface subscription_subscriptions_params {
        cancelled_at?: filter._timestamp;
    }
    interface subscription_subscriptions_params {
        has_scheduled_changes?: filter._boolean;
    }
    interface subscription_subscriptions_params {
        updated_at?: filter._timestamp;
    }
    interface subscription_subscriptions_params {
        offline_payment_method?: filter._enum;
    }
    interface subscription_subscriptions_params {
        auto_close_invoices?: filter._boolean;
    }
    interface subscription_subscriptions_params {
        channel?: filter._enum;
    }
    interface subscription_subscriptions_params {
        plan_id?: filter._string;
    }
    interface invoice_invoices_params {
        id?: filter._string;
    }
    interface invoice_invoices_params {
        subscription_id?: filter._string;
    }
    interface invoice_invoices_params {
        customer_id?: filter._string;
    }
    interface invoice_invoices_params {
        recurring?: filter._boolean;
    }
    interface invoice_invoices_params {
        status?: filter._enum;
    }
    interface invoice_invoices_params {
        price_type?: filter._enum;
    }
    interface invoice_invoices_params {
        date?: filter._timestamp;
    }
    interface invoice_invoices_params {
        paid_at?: filter._timestamp;
    }
    interface invoice_invoices_params {
        total?: filter._number;
    }
    interface invoice_invoices_params {
        amount_paid?: filter._number;
    }
    interface invoice_invoices_params {
        amount_adjusted?: filter._number;
    }
    interface invoice_invoices_params {
        credits_applied?: filter._number;
    }
    interface invoice_invoices_params {
        amount_due?: filter._number;
    }
    interface invoice_invoices_params {
        dunning_status?: filter._enum;
    }
    interface invoice_invoices_params {
        updated_at?: filter._timestamp;
    }
    interface invoice_invoices_params {
        channel?: filter._enum;
    }
    interface credit_note_credit_notes_params {
        id?: filter._string;
    }
    interface credit_note_credit_notes_params {
        customer_id?: filter._string;
    }
    interface credit_note_credit_notes_params {
        subscription_id?: filter._string;
    }
    interface credit_note_credit_notes_params {
        reference_invoice_id?: filter._string;
    }
    interface credit_note_credit_notes_params {
        type?: filter._enum;
    }
    interface credit_note_credit_notes_params {
        reason_code?: filter._enum;
    }
    interface credit_note_credit_notes_params {
        create_reason_code?: filter._string;
    }
    interface credit_note_credit_notes_params {
        status?: filter._enum;
    }
    interface credit_note_credit_notes_params {
        date?: filter._timestamp;
    }
    interface credit_note_credit_notes_params {
        total?: filter._number;
    }
    interface credit_note_credit_notes_params {
        price_type?: filter._enum;
    }
    interface credit_note_credit_notes_params {
        amount_allocated?: filter._number;
    }
    interface credit_note_credit_notes_params {
        amount_refunded?: filter._number;
    }
    interface credit_note_credit_notes_params {
        amount_available?: filter._number;
    }
    interface credit_note_credit_notes_params {
        voided_at?: filter._timestamp;
    }
    interface credit_note_credit_notes_params {
        updated_at?: filter._timestamp;
    }
    interface credit_note_credit_notes_params {
        channel?: filter._enum;
    }
    interface transaction_transactions_params {
        id?: filter._string;
    }
    interface transaction_transactions_params {
        customer_id?: filter._string;
    }
    interface transaction_transactions_params {
        subscription_id?: filter._string;
    }
    interface transaction_transactions_params {
        payment_source_id?: filter._string;
    }
    interface transaction_transactions_params {
        payment_method?: filter._enum;
    }
    interface transaction_transactions_params {
        gateway?: filter._enum;
    }
    interface transaction_transactions_params {
        gateway_account_id?: filter._string;
    }
    interface transaction_transactions_params {
        id_at_gateway?: filter._string;
    }
    interface transaction_transactions_params {
        reference_number?: filter._string;
    }
    interface transaction_transactions_params {
        type?: filter._enum;
    }
    interface transaction_transactions_params {
        date?: filter._timestamp;
    }
    interface transaction_transactions_params {
        amount?: filter._number;
    }
    interface transaction_transactions_params {
        amount_capturable?: filter._number;
    }
    interface transaction_transactions_params {
        status?: filter._enum;
    }
    interface transaction_transactions_params {
        updated_at?: filter._timestamp;
    }
    interface order_orders_params {
        id?: filter._string;
    }
    interface order_orders_params {
        subscription_id?: filter._string;
    }
    interface order_orders_params {
        customer_id?: filter._string;
    }
    interface order_orders_params {
        status?: filter._enum;
    }
    interface order_orders_params {
        price_type?: filter._enum;
    }
    interface order_orders_params {
        order_date?: filter._timestamp;
    }
    interface order_orders_params {
        shipping_date?: filter._timestamp;
    }
    interface order_orders_params {
        shipped_at?: filter._timestamp;
    }
    interface order_orders_params {
        delivered_at?: filter._timestamp;
    }
    interface order_orders_params {
        cancelled_at?: filter._timestamp;
    }
    interface order_orders_params {
        amount_paid?: filter._number;
    }
    interface order_orders_params {
        refundable_credits?: filter._number;
    }
    interface order_orders_params {
        refundable_credits_issued?: filter._number;
    }
    interface order_orders_params {
        updated_at?: filter._timestamp;
    }
    interface order_orders_params {
        resent_status?: filter._enum;
    }
    interface order_orders_params {
        is_resent?: filter._boolean;
    }
    interface order_orders_params {
        original_order_id?: filter._string;
    }
    interface item_family_item_families_params {
        id?: filter._string;
    }
    interface item_family_item_families_params {
        name?: filter._string;
    }
    interface item_family_item_families_params {
        updated_at?: filter._timestamp;
    }
    interface item_items_params {
        id?: filter._string;
    }
    interface item_items_params {
        item_family_id?: filter._string;
    }
    interface item_items_params {
        type?: filter._enum;
    }
    interface item_items_params {
        name?: filter._string;
    }
    interface item_items_params {
        item_applicability?: filter._enum;
    }
    interface item_items_params {
        status?: filter._enum;
    }
    interface item_items_params {
        is_giftable?: filter._boolean;
    }
    interface item_items_params {
        updated_at?: filter._timestamp;
    }
    interface item_items_params {
        enabled_for_checkout?: filter._boolean;
    }
    interface item_items_params {
        enabled_in_portal?: filter._boolean;
    }
    interface item_items_params {
        metered?: filter._boolean;
    }
    interface item_items_params {
        usage_calculation?: filter._enum;
    }
    interface item_items_params {
        channel?: filter._enum;
    }
    interface item_price_item_prices_params {
        id?: filter._string;
    }
    interface item_price_item_prices_params {
        name?: filter._string;
    }
    interface item_price_item_prices_params {
        pricing_model?: filter._enum;
    }
    interface item_price_item_prices_params {
        item_id?: filter._string;
    }
    interface item_price_item_prices_params {
        price_variant_id?: filter._string;
    }
    interface item_price_item_prices_params {
        trial_period?: filter._number;
    }
    interface item_price_item_prices_params {
        trial_period_unit?: filter._enum;
    }
    interface item_price_item_prices_params {
        status?: filter._enum;
    }
    interface item_price_item_prices_params {
        updated_at?: filter._timestamp;
    }
    interface item_price_item_prices_params {
        period_unit?: filter._enum;
    }
    interface item_price_item_prices_params {
        period?: filter._number;
    }
    interface item_price_item_prices_params {
        channel?: filter._enum;
    }
    interface attached_item_attached_items_params {
        id?: filter._string;
    }
    interface attached_item_attached_items_params {
        item_id?: filter._string;
    }
    interface attached_item_attached_items_params {
        type?: filter._enum;
    }
    interface attached_item_attached_items_params {
        charge_on_event?: filter._enum;
    }
    interface attached_item_attached_items_params {
        updated_at?: filter._timestamp;
    }
    interface attached_item_attached_items_params {
        parent_item_id?: filter._string;
    }
    interface differential_price_differential_prices_params {
        item_price_id?: filter._string;
    }
    interface differential_price_differential_prices_params {
        id?: filter._string;
    }
    interface differential_price_differential_prices_params {
        parent_item_id?: filter._string;
    }
    interface price_variant_price_variants_params {
        id?: filter._string;
    }
    interface price_variant_price_variants_params {
        name?: filter._string;
    }
    interface price_variant_price_variants_params {
        status?: filter._enum;
    }
    interface price_variant_price_variants_params {
        updated_at?: filter._timestamp;
    }
    interface price_variant_price_variants_params {
        created_at?: filter._timestamp;
    }
}
