import { ListResult } from '../list_result';
import { RequestWrapper } from "../request_wrapper";
import { Model } from "./model";
import { filter } from "../filter";
export declare class Invoice extends Model {
    id: string;
    po_number?: string;
    customer_id: string;
    subscription_id?: string;
    recurring: boolean;
    status: string;
    vat_number?: string;
    price_type: string;
    date?: number;
    due_date?: number;
    net_term_days?: number;
    exchange_rate?: number;
    currency_code: string;
    total?: number;
    amount_paid?: number;
    amount_adjusted?: number;
    write_off_amount?: number;
    credits_applied?: number;
    amount_due?: number;
    paid_at?: number;
    dunning_status?: string;
    next_retry_at?: number;
    voided_at?: number;
    resource_version?: number;
    updated_at?: number;
    sub_total: number;
    sub_total_in_local_currency?: number;
    total_in_local_currency?: number;
    local_currency_code?: string;
    tax: number;
    local_currency_exchange_rate?: number;
    first_invoice?: boolean;
    new_sales_amount?: number;
    has_advance_charges?: boolean;
    term_finalized: boolean;
    is_gifted: boolean;
    generated_at?: number;
    expected_payment_date?: number;
    amount_to_collect?: number;
    round_off_amount?: number;
    line_items?: Array<LineItem>;
    discounts?: Array<Discount>;
    line_item_discounts?: Array<LineItemDiscount>;
    taxes?: Array<Tax>;
    line_item_taxes?: Array<LineItemTax>;
    line_item_credits?: Array<LineItemCredit>;
    line_item_tiers?: Array<LineItemTier>;
    linked_payments?: Array<LinkedPayment>;
    dunning_attempts?: Array<DunningAttempt>;
    applied_credits?: Array<AppliedCredit>;
    adjustment_credit_notes?: Array<AdjustmentCreditNote>;
    issued_credit_notes?: Array<IssuedCreditNote>;
    linked_orders?: Array<LinkedOrder>;
    notes?: Array<Note>;
    shipping_address?: ShippingAddress;
    statement_descriptor?: StatementDescriptor;
    billing_address?: BillingAddress;
    einvoice?: Einvoice;
    payment_owner?: string;
    void_reason_code?: string;
    deleted: boolean;
    tax_category?: string;
    vat_number_prefix?: string;
    channel?: string;
    business_entity_id?: string;
    site_details_at_creation?: SiteDetailsAtCreation;
    tax_origin?: TaxOrigin;
    line_item_addresses?: Array<LineItemAddress>;
    static create(params?: _invoice.create_params): RequestWrapper;
    static create_for_charge_items_and_charges(params?: _invoice.create_for_charge_items_and_charges_params): RequestWrapper;
    static charge(params?: _invoice.charge_params): RequestWrapper;
    static charge_addon(params?: _invoice.charge_addon_params): RequestWrapper;
    static create_for_charge_item(params?: _invoice.create_for_charge_item_params): RequestWrapper;
    static stop_dunning(invoice_id: string, params?: _invoice.stop_dunning_params): RequestWrapper;
    static pause_dunning(invoice_id: string, params?: _invoice.pause_dunning_params): RequestWrapper;
    static resume_dunning(invoice_id: string, params?: _invoice.resume_dunning_params): RequestWrapper;
    static import_invoice(params?: _invoice.import_invoice_params): RequestWrapper;
    static apply_payments(invoice_id: string, params?: _invoice.apply_payments_params): RequestWrapper;
    static sync_usages(invoice_id: string, params?: any): RequestWrapper;
    static delete_line_items(invoice_id: string, params?: _invoice.delete_line_items_params): RequestWrapper;
    static apply_credits(invoice_id: string, params?: _invoice.apply_credits_params): RequestWrapper;
    static list(params?: _invoice.invoice_list_params): RequestWrapper<ListResult>;
    static invoices_for_customer(customer_id: string, params?: any): RequestWrapper<ListResult>;
    static invoices_for_subscription(subscription_id: string, params?: any): RequestWrapper<ListResult>;
    static retrieve(invoice_id: string, params?: _invoice.retrieve_params): RequestWrapper;
    static pdf(invoice_id: string, params?: _invoice.pdf_params): RequestWrapper;
    static download_einvoice(invoice_id: string, params?: any): RequestWrapper;
    static list_payment_reference_numbers(params?: _invoice.invoice_list_payment_reference_numbers_params): RequestWrapper<ListResult>;
    static add_charge(invoice_id: string, params?: _invoice.add_charge_params): RequestWrapper;
    static add_addon_charge(invoice_id: string, params?: _invoice.add_addon_charge_params): RequestWrapper;
    static add_charge_item(invoice_id: string, params?: _invoice.add_charge_item_params): RequestWrapper;
    static close(invoice_id: string, params?: _invoice.close_params): RequestWrapper;
    static collect_payment(invoice_id: string, params?: _invoice.collect_payment_params): RequestWrapper;
    static record_payment(invoice_id: string, params?: _invoice.record_payment_params): RequestWrapper;
    static record_tax_withheld(invoice_id: string, params?: _invoice.record_tax_withheld_params): RequestWrapper;
    static remove_tax_withheld(invoice_id: string, params?: _invoice.remove_tax_withheld_params): RequestWrapper;
    static refund(invoice_id: string, params?: _invoice.refund_params): RequestWrapper;
    static record_refund(invoice_id: string, params?: _invoice.record_refund_params): RequestWrapper;
    static remove_payment(invoice_id: string, params?: _invoice.remove_payment_params): RequestWrapper;
    static remove_credit_note(invoice_id: string, params?: _invoice.remove_credit_note_params): RequestWrapper;
    static void_invoice(invoice_id: string, params?: _invoice.void_invoice_params): RequestWrapper;
    static write_off(invoice_id: string, params?: _invoice.write_off_params): RequestWrapper;
    static delete(invoice_id: string, params?: _invoice.delete_params): RequestWrapper;
    static update_details(invoice_id: string, params?: _invoice.update_details_params): RequestWrapper;
    static apply_payment_schedule_scheme(invoice_id: string, params?: _invoice.apply_payment_schedule_scheme_params): RequestWrapper;
    static payment_schedules(invoice_id: string, params?: any): RequestWrapper;
    static resend_einvoice(invoice_id: string, params?: any): RequestWrapper;
    static send_einvoice(invoice_id: string, params?: any): RequestWrapper;
}
export declare class LineItem extends Model {
    id?: string;
    subscription_id?: string;
    date_from: number;
    date_to: number;
    unit_amount: number;
    quantity?: number;
    amount?: number;
    pricing_model?: string;
    is_taxed: boolean;
    tax_amount?: number;
    tax_rate?: number;
    unit_amount_in_decimal?: string;
    quantity_in_decimal?: string;
    amount_in_decimal?: string;
    discount_amount?: number;
    item_level_discount_amount?: number;
    metered?: boolean;
    is_percentage_pricing?: boolean;
    reference_line_item_id?: string;
    description: string;
    entity_description?: string;
    entity_type: string;
    tax_exempt_reason?: string;
    entity_id?: string;
    customer_id?: string;
}
export declare class Discount extends Model {
    amount: number;
    description?: string;
    entity_type: string;
    discount_type?: string;
    entity_id?: string;
    coupon_set_code?: string;
}
export declare class LineItemDiscount extends Model {
    line_item_id: string;
    discount_type: string;
    coupon_id?: string;
    entity_id?: string;
    discount_amount: number;
}
export declare class Tax extends Model {
    name: string;
    amount: number;
    description?: string;
}
export declare class LineItemTax extends Model {
    line_item_id?: string;
    tax_name: string;
    tax_rate: number;
    date_to?: number;
    date_from?: number;
    prorated_taxable_amount?: number;
    is_partial_tax_applied?: boolean;
    is_non_compliance_tax?: boolean;
    taxable_amount: number;
    tax_amount: number;
    tax_juris_type?: string;
    tax_juris_name?: string;
    tax_juris_code?: string;
    tax_amount_in_local_currency?: number;
    local_currency_code?: string;
}
export declare class LineItemCredit extends Model {
    cn_id: string;
    applied_amount: number;
    line_item_id?: string;
}
export declare class LineItemTier extends Model {
    line_item_id?: string;
    starting_unit: number;
    ending_unit?: number;
    quantity_used: number;
    unit_amount: number;
    starting_unit_in_decimal?: string;
    ending_unit_in_decimal?: string;
    quantity_used_in_decimal?: string;
    unit_amount_in_decimal?: string;
    pricing_type?: string;
    package_size?: number;
}
export declare class LinkedPayment extends Model {
    txn_id: string;
    applied_amount: number;
    applied_at: number;
    txn_status?: string;
    txn_date?: number;
    txn_amount?: number;
}
export declare class DunningAttempt extends Model {
    attempt: number;
    transaction_id?: string;
    dunning_type: string;
    created_at?: number;
    txn_status?: string;
    txn_amount?: number;
}
export declare class AppliedCredit extends Model {
    cn_id: string;
    applied_amount: number;
    applied_at: number;
    cn_reason_code?: string;
    cn_create_reason_code?: string;
    cn_date?: number;
    cn_status: string;
    tax_application?: string;
}
export declare class AdjustmentCreditNote extends Model {
    cn_id: string;
    cn_reason_code?: string;
    cn_create_reason_code?: string;
    cn_date?: number;
    cn_total?: number;
    cn_status: string;
}
export declare class IssuedCreditNote extends Model {
    cn_id: string;
    cn_reason_code?: string;
    cn_create_reason_code?: string;
    cn_date?: number;
    cn_total?: number;
    cn_status: string;
}
export declare class LinkedOrder extends Model {
    id: string;
    document_number?: string;
    status?: string;
    order_type?: string;
    reference_id?: string;
    fulfillment_status?: string;
    batch_id?: string;
    created_at: number;
}
export declare class Note extends Model {
    note: string;
    entity_id?: string;
    entity_type?: string;
}
export declare class ShippingAddress extends Model {
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
    index: number;
}
export declare class StatementDescriptor extends Model {
    id: string;
    descriptor?: string;
}
export declare class BillingAddress extends Model {
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
}
export declare class Einvoice extends Model {
    id: string;
    reference_number?: string;
    status: string;
    message?: string;
}
export declare class SiteDetailsAtCreation extends Model {
    timezone?: string;
    organization_address?: any;
}
export declare class TaxOrigin extends Model {
    country?: string;
    registration_number?: string;
}
export declare class LineItemAddress extends Model {
    line_item_id?: string;
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
}
export declare namespace _invoice {
    interface create_params {
        customer_id?: string;
        subscription_id?: string;
        currency_code?: string;
        invoice_date?: number;
        invoice_note?: string;
        remove_general_note?: boolean;
        po_number?: string;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        coupon_ids?: Array<string>;
        authorization_transaction_id?: string;
        payment_source_id?: string;
        auto_collection?: string;
        token_id?: string;
        replace_primary_payment_source?: boolean;
        retain_payment_source?: boolean;
        payment_initiator?: string;
        shipping_address?: shipping_address_create_params;
        statement_descriptor?: statement_descriptor_create_params;
        card?: card_create_params;
        bank_account?: bank_account_create_params;
        payment_method?: payment_method_create_params;
        payment_intent?: payment_intent_create_params;
        addons?: Array<addons_create_params>;
        charges?: Array<charges_create_params>;
        tax_providers_fields?: Array<tax_providers_fields_create_params>;
        notes_to_remove?: Array<notes_to_remove_create_params>;
    }
    interface create_for_charge_items_and_charges_params {
        customer_id?: string;
        subscription_id?: string;
        currency_code?: string;
        invoice_note?: string;
        remove_general_note?: boolean;
        po_number?: string;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        coupon_ids?: Array<string>;
        authorization_transaction_id?: string;
        payment_source_id?: string;
        auto_collection?: string;
        invoice_date?: number;
        token_id?: string;
        replace_primary_payment_source?: boolean;
        retain_payment_source?: boolean;
        payment_initiator?: string;
        shipping_address?: shipping_address_create_for_charge_items_and_charges_params;
        statement_descriptor?: statement_descriptor_create_for_charge_items_and_charges_params;
        card?: card_create_for_charge_items_and_charges_params;
        bank_account?: bank_account_create_for_charge_items_and_charges_params;
        payment_method?: payment_method_create_for_charge_items_and_charges_params;
        payment_intent?: payment_intent_create_for_charge_items_and_charges_params;
        item_prices?: Array<item_prices_create_for_charge_items_and_charges_params>;
        item_tiers?: Array<item_tiers_create_for_charge_items_and_charges_params>;
        charges?: Array<charges_create_for_charge_items_and_charges_params>;
        notes_to_remove?: Array<notes_to_remove_create_for_charge_items_and_charges_params>;
        tax_providers_fields?: Array<tax_providers_fields_create_for_charge_items_and_charges_params>;
        discounts?: Array<discounts_create_for_charge_items_and_charges_params>;
    }
    interface charge_params {
        customer_id?: string;
        subscription_id?: string;
        currency_code?: string;
        amount?: number;
        amount_in_decimal?: string;
        description: string;
        date_from?: number;
        date_to?: number;
        coupon_ids?: Array<string>;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        avalara_sale_type?: string;
        avalara_transaction_type?: number;
        avalara_service_type?: number;
        po_number?: string;
        invoice_date?: number;
        payment_source_id?: string;
        payment_initiator?: string;
        tax_providers_fields?: Array<tax_providers_fields_charge_params>;
    }
    interface charge_addon_params {
        customer_id?: string;
        subscription_id?: string;
        addon_id: string;
        addon_quantity?: number;
        addon_unit_price?: number;
        addon_quantity_in_decimal?: string;
        addon_unit_price_in_decimal?: string;
        date_from?: number;
        date_to?: number;
        coupon_ids?: Array<string>;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        po_number?: string;
        invoice_date?: number;
        payment_source_id?: string;
        payment_initiator?: string;
    }
    interface create_for_charge_item_params {
        customer_id?: string;
        subscription_id?: string;
        po_number?: string;
        coupon?: string;
        payment_source_id?: string;
        payment_initiator?: string;
        invoice_date?: number;
        item_price?: item_price_create_for_charge_item_params;
        item_tiers?: Array<item_tiers_create_for_charge_item_params>;
    }
    interface stop_dunning_params {
        comment?: string;
    }
    interface pause_dunning_params {
        expected_payment_date: number;
        comment?: string;
    }
    interface resume_dunning_params {
        comment?: string;
    }
    interface import_invoice_params {
        id: string;
        currency_code?: string;
        customer_id?: string;
        subscription_id?: string;
        po_number?: string;
        price_type?: string;
        tax_override_reason?: string;
        vat_number?: string;
        vat_number_prefix?: string;
        date: number;
        total: number;
        round_off?: number;
        status?: string;
        voided_at?: number;
        void_reason_code?: string;
        is_written_off?: boolean;
        write_off_amount?: number;
        write_off_date?: number;
        due_date?: number;
        net_term_days?: number;
        has_advance_charges?: boolean;
        use_for_proration?: boolean;
        credit_note?: credit_note_import_invoice_params;
        billing_address?: billing_address_import_invoice_params;
        shipping_address?: shipping_address_import_invoice_params;
        line_items?: Array<line_items_import_invoice_params>;
        payment_reference_numbers?: Array<payment_reference_numbers_import_invoice_params>;
        line_item_tiers?: Array<line_item_tiers_import_invoice_params>;
        discounts?: Array<discounts_import_invoice_params>;
        taxes?: Array<taxes_import_invoice_params>;
        payments?: Array<payments_import_invoice_params>;
        notes?: Array<notes_import_invoice_params>;
        line_item_addresses?: Array<line_item_addresses_import_invoice_params>;
    }
    interface apply_payments_params {
        comment?: string;
        transactions?: Array<transactions_apply_payments_params>;
    }
    interface delete_line_items_params {
        line_items?: Array<line_items_delete_line_items_params>;
    }
    interface apply_credits_params {
        comment?: string;
        credit_notes?: Array<credit_notes_apply_credits_params>;
    }
    interface invoice_list_params {
        limit?: number;
        offset?: string;
        einvoice?: einvoice_invoice_list_params;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        paid_on_after?: number;
        include_deleted?: boolean;
        id?: filter._string;
        subscription_id?: filter._string;
        customer_id?: filter._string;
        recurring?: filter._boolean;
        status?: filter._enum;
        price_type?: filter._enum;
        date?: filter._timestamp;
        paid_at?: filter._timestamp;
        total?: filter._number;
        amount_paid?: filter._number;
        amount_adjusted?: filter._number;
        credits_applied?: filter._number;
        amount_due?: filter._number;
        dunning_status?: filter._enum;
        payment_owner?: filter._string;
        updated_at?: filter._timestamp;
        channel?: filter._enum;
        voided_at?: filter._timestamp;
        void_reason_code?: filter._string;
        "sort_by[asc]"?: string;
        "sort_by[desc]"?: string;
    }
    interface retrieve_params {
        line_item?: line_item_retrieve_params;
    }
    interface pdf_params {
        disposition_type?: string;
    }
    interface invoice_list_payment_reference_numbers_params {
        limit?: number;
        offset?: string;
        payment_reference_number?: payment_reference_number_invoice_list_payment_reference_numbers_params;
        id?: filter._string;
    }
    interface add_charge_params {
        amount: number;
        description: string;
        avalara_sale_type?: string;
        avalara_transaction_type?: number;
        avalara_service_type?: number;
        avalara_tax_code?: string;
        hsn_code?: string;
        taxjar_product_code?: string;
        comment?: string;
        subscription_id?: string;
        line_item?: line_item_add_charge_params;
    }
    interface add_addon_charge_params {
        addon_id: string;
        addon_quantity?: number;
        addon_unit_price?: number;
        addon_quantity_in_decimal?: string;
        addon_unit_price_in_decimal?: string;
        comment?: string;
        subscription_id?: string;
        line_item?: line_item_add_addon_charge_params;
    }
    interface add_charge_item_params {
        comment?: string;
        subscription_id?: string;
        item_price?: item_price_add_charge_item_params;
        item_tiers?: Array<item_tiers_add_charge_item_params>;
    }
    interface close_params {
        comment?: string;
        invoice_note?: string;
        remove_general_note?: boolean;
        invoice_date?: number;
        notes_to_remove?: Array<notes_to_remove_close_params>;
    }
    interface collect_payment_params {
        amount?: number;
        authorization_transaction_id?: string;
        payment_source_id?: string;
        comment?: string;
        payment_initiator?: string;
    }
    interface record_payment_params {
        comment?: string;
        transaction?: transaction_record_payment_params;
    }
    interface record_tax_withheld_params {
        tax_withheld?: tax_withheld_record_tax_withheld_params;
    }
    interface remove_tax_withheld_params {
        tax_withheld?: tax_withheld_remove_tax_withheld_params;
    }
    interface refund_params {
        refund_amount?: number;
        comment?: string;
        customer_notes?: string;
        credit_note?: credit_note_refund_params;
    }
    interface record_refund_params {
        comment?: string;
        customer_notes?: string;
        transaction?: transaction_record_refund_params;
        credit_note?: credit_note_record_refund_params;
    }
    interface remove_payment_params {
        transaction?: transaction_remove_payment_params;
    }
    interface remove_credit_note_params {
        credit_note?: credit_note_remove_credit_note_params;
    }
    interface void_invoice_params {
        comment?: string;
        void_reason_code?: string;
    }
    interface write_off_params {
        comment?: string;
    }
    interface delete_params {
        comment?: string;
    }
    interface update_details_params {
        vat_number?: string;
        vat_number_prefix?: string;
        po_number?: string;
        comment?: string;
        billing_address?: billing_address_update_details_params;
        shipping_address?: shipping_address_update_details_params;
        statement_descriptor?: statement_descriptor_update_details_params;
    }
    interface apply_payment_schedule_scheme_params {
        scheme_id: string;
        amount?: number;
    }
    interface shipping_address_create_params {
        first_name?: string;
    }
    interface shipping_address_create_params {
        last_name?: string;
    }
    interface shipping_address_create_params {
        email?: string;
    }
    interface shipping_address_create_params {
        company?: string;
    }
    interface shipping_address_create_params {
        phone?: string;
    }
    interface shipping_address_create_params {
        line1?: string;
    }
    interface shipping_address_create_params {
        line2?: string;
    }
    interface shipping_address_create_params {
        line3?: string;
    }
    interface shipping_address_create_params {
        city?: string;
    }
    interface shipping_address_create_params {
        state_code?: string;
    }
    interface shipping_address_create_params {
        state?: string;
    }
    interface shipping_address_create_params {
        zip?: string;
    }
    interface shipping_address_create_params {
        country?: string;
    }
    interface shipping_address_create_params {
        validation_status?: string;
    }
    interface statement_descriptor_create_params {
        descriptor?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_create_params {
        gateway_account_id?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_create_params {
        first_name?: string;
    }
    interface card_create_params {
        last_name?: string;
    }
    interface card_create_params {
        number?: string;
    }
    interface card_create_params {
        expiry_month?: number;
    }
    interface card_create_params {
        expiry_year?: number;
    }
    interface card_create_params {
        cvv?: string;
    }
    interface card_create_params {
        preferred_scheme?: string;
    }
    interface card_create_params {
        billing_addr1?: string;
    }
    interface card_create_params {
        billing_addr2?: string;
    }
    interface card_create_params {
        billing_city?: string;
    }
    interface card_create_params {
        billing_state_code?: string;
    }
    interface card_create_params {
        billing_state?: string;
    }
    interface card_create_params {
        billing_zip?: string;
    }
    interface card_create_params {
        billing_country?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        ip_address?: string;
    }
    interface card_create_params {
        additional_information?: any;
    }
    interface bank_account_create_params {
        gateway_account_id?: string;
    }
    interface bank_account_create_params {
        iban?: string;
    }
    interface bank_account_create_params {
        first_name?: string;
    }
    interface bank_account_create_params {
        last_name?: string;
    }
    interface bank_account_create_params {
        company?: string;
    }
    interface bank_account_create_params {
        email?: string;
    }
    interface bank_account_create_params {
        phone?: string;
    }
    interface bank_account_create_params {
        bank_name?: string;
    }
    interface bank_account_create_params {
        account_number?: string;
    }
    interface bank_account_create_params {
        routing_number?: string;
    }
    interface bank_account_create_params {
        bank_code?: string;
    }
    interface bank_account_create_params {
        account_type?: string;
    }
    interface bank_account_create_params {
        account_holder_type?: string;
    }
    interface bank_account_create_params {
        echeck_type?: string;
    }
    interface bank_account_create_params {
        issuing_country?: string;
    }
    interface bank_account_create_params {
        swedish_identity_number?: string;
    }
    interface bank_account_create_params {
        billing_address?: any;
    }
    interface payment_method_create_params {
        type?: string;
    }
    interface payment_method_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_create_params {
        gateway_account_id?: string;
    }
    interface payment_method_create_params {
        reference_id?: string;
    }
    interface payment_method_create_params {
        tmp_token?: string;
    }
    interface payment_method_create_params {
        issuing_country?: string;
    }
    interface payment_method_create_params {
        additional_information?: any;
    }
    interface payment_intent_create_params {
        id?: string;
    }
    interface payment_intent_create_params {
        gateway_account_id?: string;
    }
    interface payment_intent_create_params {
        gw_token?: string;
    }
    interface payment_intent_create_params {
        payment_method_type?: string;
    }
    interface payment_intent_create_params {
        reference_id?: string;
    }
    interface payment_intent_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_create_params {
        additional_information?: any;
    }
    interface addons_create_params {
        id?: string;
    }
    interface addons_create_params {
        quantity?: number;
    }
    interface addons_create_params {
        unit_price?: number;
    }
    interface addons_create_params {
        quantity_in_decimal?: string;
    }
    interface addons_create_params {
        unit_price_in_decimal?: string;
    }
    interface addons_create_params {
        date_from?: number;
    }
    interface addons_create_params {
        date_to?: number;
    }
    interface charges_create_params {
        amount?: number;
    }
    interface charges_create_params {
        amount_in_decimal?: string;
    }
    interface charges_create_params {
        description?: string;
    }
    interface charges_create_params {
        taxable?: boolean;
    }
    interface charges_create_params {
        tax_profile_id?: string;
    }
    interface charges_create_params {
        avalara_tax_code?: string;
    }
    interface charges_create_params {
        hsn_code?: string;
    }
    interface charges_create_params {
        taxjar_product_code?: string;
    }
    interface charges_create_params {
        avalara_sale_type?: string;
    }
    interface charges_create_params {
        avalara_transaction_type?: number;
    }
    interface charges_create_params {
        avalara_service_type?: number;
    }
    interface charges_create_params {
        date_from?: number;
    }
    interface charges_create_params {
        date_to?: number;
    }
    interface tax_providers_fields_create_params {
        provider_name?: string;
    }
    interface tax_providers_fields_create_params {
        field_id?: string;
    }
    interface tax_providers_fields_create_params {
        field_value?: string;
    }
    interface notes_to_remove_create_params {
        entity_type?: string;
    }
    interface notes_to_remove_create_params {
        entity_id?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        email?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        company?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line1?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line2?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line3?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        city?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        state_code?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        state?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        zip?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        country?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        validation_status?: string;
    }
    interface statement_descriptor_create_for_charge_items_and_charges_params {
        descriptor?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        gateway_account_id?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        number?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        expiry_month?: number;
    }
    interface card_create_for_charge_items_and_charges_params {
        expiry_year?: number;
    }
    interface card_create_for_charge_items_and_charges_params {
        cvv?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        preferred_scheme?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_addr1?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_addr2?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_city?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_state_code?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_state?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_zip?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        billing_country?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        ip_address?: string;
    }
    interface card_create_for_charge_items_and_charges_params {
        additional_information?: any;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        gateway_account_id?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        iban?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        company?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        email?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        bank_name?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        account_number?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        routing_number?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        bank_code?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        account_type?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        account_holder_type?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        echeck_type?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        issuing_country?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        swedish_identity_number?: string;
    }
    interface bank_account_create_for_charge_items_and_charges_params {
        billing_address?: any;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        type?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        gateway_account_id?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        reference_id?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        tmp_token?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        issuing_country?: string;
    }
    interface payment_method_create_for_charge_items_and_charges_params {
        additional_information?: any;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        id?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        gateway_account_id?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        gw_token?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        payment_method_type?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        reference_id?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_create_for_charge_items_and_charges_params {
        additional_information?: any;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        quantity?: number;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        quantity_in_decimal?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        unit_price?: number;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        unit_price_in_decimal?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        date_from?: number;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        date_to?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        starting_unit?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        ending_unit?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        price?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        price_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        pricing_type?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        package_size?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        amount_in_decimal?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        description?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        taxable?: boolean;
    }
    interface charges_create_for_charge_items_and_charges_params {
        tax_profile_id?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_tax_code?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        hsn_code?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        taxjar_product_code?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_sale_type?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_transaction_type?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_service_type?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        date_from?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        date_to?: number;
    }
    interface notes_to_remove_create_for_charge_items_and_charges_params {
        entity_type?: string;
    }
    interface notes_to_remove_create_for_charge_items_and_charges_params {
        entity_id?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        provider_name?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        field_id?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        field_value?: string;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        percentage?: number;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        apply_on: string;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface tax_providers_fields_charge_params {
        provider_name?: string;
    }
    interface tax_providers_fields_charge_params {
        field_id?: string;
    }
    interface tax_providers_fields_charge_params {
        field_value?: string;
    }
    interface item_price_create_for_charge_item_params {
        item_price_id: string;
    }
    interface item_price_create_for_charge_item_params {
        quantity?: number;
    }
    interface item_price_create_for_charge_item_params {
        quantity_in_decimal?: string;
    }
    interface item_price_create_for_charge_item_params {
        unit_price?: number;
    }
    interface item_price_create_for_charge_item_params {
        unit_price_in_decimal?: string;
    }
    interface item_price_create_for_charge_item_params {
        date_from?: number;
    }
    interface item_price_create_for_charge_item_params {
        date_to?: number;
    }
    interface item_tiers_create_for_charge_item_params {
        starting_unit?: number;
    }
    interface item_tiers_create_for_charge_item_params {
        ending_unit?: number;
    }
    interface item_tiers_create_for_charge_item_params {
        price?: number;
    }
    interface item_tiers_create_for_charge_item_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_item_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_item_params {
        price_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_item_params {
        pricing_type?: string;
    }
    interface item_tiers_create_for_charge_item_params {
        package_size?: number;
    }
    interface credit_note_import_invoice_params {
        id?: string;
    }
    interface billing_address_import_invoice_params {
        first_name?: string;
    }
    interface billing_address_import_invoice_params {
        last_name?: string;
    }
    interface billing_address_import_invoice_params {
        email?: string;
    }
    interface billing_address_import_invoice_params {
        company?: string;
    }
    interface billing_address_import_invoice_params {
        phone?: string;
    }
    interface billing_address_import_invoice_params {
        line1?: string;
    }
    interface billing_address_import_invoice_params {
        line2?: string;
    }
    interface billing_address_import_invoice_params {
        line3?: string;
    }
    interface billing_address_import_invoice_params {
        city?: string;
    }
    interface billing_address_import_invoice_params {
        state_code?: string;
    }
    interface billing_address_import_invoice_params {
        state?: string;
    }
    interface billing_address_import_invoice_params {
        zip?: string;
    }
    interface billing_address_import_invoice_params {
        country?: string;
    }
    interface billing_address_import_invoice_params {
        validation_status?: string;
    }
    interface shipping_address_import_invoice_params {
        first_name?: string;
    }
    interface shipping_address_import_invoice_params {
        last_name?: string;
    }
    interface shipping_address_import_invoice_params {
        email?: string;
    }
    interface shipping_address_import_invoice_params {
        company?: string;
    }
    interface shipping_address_import_invoice_params {
        phone?: string;
    }
    interface shipping_address_import_invoice_params {
        line1?: string;
    }
    interface shipping_address_import_invoice_params {
        line2?: string;
    }
    interface shipping_address_import_invoice_params {
        line3?: string;
    }
    interface shipping_address_import_invoice_params {
        city?: string;
    }
    interface shipping_address_import_invoice_params {
        state_code?: string;
    }
    interface shipping_address_import_invoice_params {
        state?: string;
    }
    interface shipping_address_import_invoice_params {
        zip?: string;
    }
    interface shipping_address_import_invoice_params {
        country?: string;
    }
    interface shipping_address_import_invoice_params {
        validation_status?: string;
    }
    interface line_items_import_invoice_params {
        id?: string;
    }
    interface line_items_import_invoice_params {
        date_from?: number;
    }
    interface line_items_import_invoice_params {
        date_to?: number;
    }
    interface line_items_import_invoice_params {
        subscription_id?: string;
    }
    interface line_items_import_invoice_params {
        description: string;
    }
    interface line_items_import_invoice_params {
        unit_amount?: number;
    }
    interface line_items_import_invoice_params {
        quantity?: number;
    }
    interface line_items_import_invoice_params {
        amount?: number;
    }
    interface line_items_import_invoice_params {
        unit_amount_in_decimal?: string;
    }
    interface line_items_import_invoice_params {
        quantity_in_decimal?: string;
    }
    interface line_items_import_invoice_params {
        amount_in_decimal?: string;
    }
    interface line_items_import_invoice_params {
        entity_type?: string;
    }
    interface line_items_import_invoice_params {
        entity_id?: string;
    }
    interface line_items_import_invoice_params {
        item_level_discount1_entity_id?: string;
    }
    interface line_items_import_invoice_params {
        item_level_discount1_amount?: number;
    }
    interface line_items_import_invoice_params {
        item_level_discount2_entity_id?: string;
    }
    interface line_items_import_invoice_params {
        item_level_discount2_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax1_name?: string;
    }
    interface line_items_import_invoice_params {
        tax1_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax2_name?: string;
    }
    interface line_items_import_invoice_params {
        tax2_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax3_name?: string;
    }
    interface line_items_import_invoice_params {
        tax3_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax4_name?: string;
    }
    interface line_items_import_invoice_params {
        tax4_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax5_name?: string;
    }
    interface line_items_import_invoice_params {
        tax5_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax6_name?: string;
    }
    interface line_items_import_invoice_params {
        tax6_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax7_name?: string;
    }
    interface line_items_import_invoice_params {
        tax7_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax8_name?: string;
    }
    interface line_items_import_invoice_params {
        tax8_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax9_name?: string;
    }
    interface line_items_import_invoice_params {
        tax9_amount?: number;
    }
    interface line_items_import_invoice_params {
        tax10_name?: string;
    }
    interface line_items_import_invoice_params {
        tax10_amount?: number;
    }
    interface line_items_import_invoice_params {
        created_at?: number;
    }
    interface payment_reference_numbers_import_invoice_params {
        id?: string;
    }
    interface payment_reference_numbers_import_invoice_params {
        type: string;
    }
    interface payment_reference_numbers_import_invoice_params {
        number: string;
    }
    interface line_item_tiers_import_invoice_params {
        line_item_id: string;
    }
    interface line_item_tiers_import_invoice_params {
        starting_unit?: number;
    }
    interface line_item_tiers_import_invoice_params {
        ending_unit?: number;
    }
    interface line_item_tiers_import_invoice_params {
        quantity_used?: number;
    }
    interface line_item_tiers_import_invoice_params {
        unit_amount?: number;
    }
    interface line_item_tiers_import_invoice_params {
        starting_unit_in_decimal?: string;
    }
    interface line_item_tiers_import_invoice_params {
        ending_unit_in_decimal?: string;
    }
    interface line_item_tiers_import_invoice_params {
        quantity_used_in_decimal?: string;
    }
    interface line_item_tiers_import_invoice_params {
        unit_amount_in_decimal?: string;
    }
    interface discounts_import_invoice_params {
        entity_type: string;
    }
    interface discounts_import_invoice_params {
        entity_id?: string;
    }
    interface discounts_import_invoice_params {
        description?: string;
    }
    interface discounts_import_invoice_params {
        amount: number;
    }
    interface taxes_import_invoice_params {
        name: string;
    }
    interface taxes_import_invoice_params {
        rate: number;
    }
    interface taxes_import_invoice_params {
        amount?: number;
    }
    interface taxes_import_invoice_params {
        description?: string;
    }
    interface taxes_import_invoice_params {
        juris_type?: string;
    }
    interface taxes_import_invoice_params {
        juris_name?: string;
    }
    interface taxes_import_invoice_params {
        juris_code?: string;
    }
    interface payments_import_invoice_params {
        amount: number;
    }
    interface payments_import_invoice_params {
        payment_method: string;
    }
    interface payments_import_invoice_params {
        date?: number;
    }
    interface payments_import_invoice_params {
        reference_number?: string;
    }
    interface notes_import_invoice_params {
        entity_type?: string;
    }
    interface notes_import_invoice_params {
        entity_id?: string;
    }
    interface notes_import_invoice_params {
        note?: string;
    }
    interface line_item_addresses_import_invoice_params {
        line_item_id?: string;
    }
    interface line_item_addresses_import_invoice_params {
        first_name?: string;
    }
    interface line_item_addresses_import_invoice_params {
        last_name?: string;
    }
    interface line_item_addresses_import_invoice_params {
        email?: string;
    }
    interface line_item_addresses_import_invoice_params {
        company?: string;
    }
    interface line_item_addresses_import_invoice_params {
        phone?: string;
    }
    interface line_item_addresses_import_invoice_params {
        line1?: string;
    }
    interface line_item_addresses_import_invoice_params {
        line2?: string;
    }
    interface line_item_addresses_import_invoice_params {
        line3?: string;
    }
    interface line_item_addresses_import_invoice_params {
        city?: string;
    }
    interface line_item_addresses_import_invoice_params {
        state_code?: string;
    }
    interface line_item_addresses_import_invoice_params {
        state?: string;
    }
    interface line_item_addresses_import_invoice_params {
        zip?: string;
    }
    interface line_item_addresses_import_invoice_params {
        country?: string;
    }
    interface line_item_addresses_import_invoice_params {
        validation_status?: string;
    }
    interface transactions_apply_payments_params {
        id?: string;
    }
    interface transactions_apply_payments_params {
        amount?: number;
    }
    interface line_items_delete_line_items_params {
        id?: string;
    }
    interface credit_notes_apply_credits_params {
        id?: string;
    }
    interface einvoice_invoice_list_params {
        status?: filter._enum;
    }
    interface line_item_retrieve_params {
        subscription_id?: filter._string;
    }
    interface line_item_retrieve_params {
        customer_id?: filter._string;
    }
    interface payment_reference_number_invoice_list_payment_reference_numbers_params {
        number?: filter._string;
    }
    interface line_item_add_charge_params {
        date_from?: number;
    }
    interface line_item_add_charge_params {
        date_to?: number;
    }
    interface line_item_add_addon_charge_params {
        date_from?: number;
    }
    interface line_item_add_addon_charge_params {
        date_to?: number;
    }
    interface item_price_add_charge_item_params {
        item_price_id: string;
    }
    interface item_price_add_charge_item_params {
        quantity?: number;
    }
    interface item_price_add_charge_item_params {
        quantity_in_decimal?: string;
    }
    interface item_price_add_charge_item_params {
        unit_price?: number;
    }
    interface item_price_add_charge_item_params {
        unit_price_in_decimal?: string;
    }
    interface item_price_add_charge_item_params {
        date_from?: number;
    }
    interface item_price_add_charge_item_params {
        date_to?: number;
    }
    interface item_tiers_add_charge_item_params {
        starting_unit?: number;
    }
    interface item_tiers_add_charge_item_params {
        ending_unit?: number;
    }
    interface item_tiers_add_charge_item_params {
        price?: number;
    }
    interface item_tiers_add_charge_item_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_add_charge_item_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_add_charge_item_params {
        price_in_decimal?: string;
    }
    interface item_tiers_add_charge_item_params {
        pricing_type?: string;
    }
    interface item_tiers_add_charge_item_params {
        package_size?: number;
    }
    interface notes_to_remove_close_params {
        entity_type?: string;
    }
    interface notes_to_remove_close_params {
        entity_id?: string;
    }
    interface transaction_record_payment_params {
        amount?: number;
    }
    interface transaction_record_payment_params {
        payment_method: string;
    }
    interface transaction_record_payment_params {
        reference_number?: string;
    }
    interface transaction_record_payment_params {
        custom_payment_method_id?: string;
    }
    interface transaction_record_payment_params {
        id_at_gateway?: string;
    }
    interface transaction_record_payment_params {
        status?: string;
    }
    interface transaction_record_payment_params {
        date?: number;
    }
    interface transaction_record_payment_params {
        error_code?: string;
    }
    interface transaction_record_payment_params {
        error_text?: string;
    }
    interface tax_withheld_record_tax_withheld_params {
        amount: number;
    }
    interface tax_withheld_record_tax_withheld_params {
        reference_number?: string;
    }
    interface tax_withheld_record_tax_withheld_params {
        date?: number;
    }
    interface tax_withheld_record_tax_withheld_params {
        description?: string;
    }
    interface tax_withheld_remove_tax_withheld_params {
        id: string;
    }
    interface credit_note_refund_params {
        reason_code?: string;
    }
    interface credit_note_refund_params {
        create_reason_code?: string;
    }
    interface transaction_record_refund_params {
        amount?: number;
    }
    interface transaction_record_refund_params {
        payment_method: string;
    }
    interface transaction_record_refund_params {
        reference_number?: string;
    }
    interface transaction_record_refund_params {
        custom_payment_method_id?: string;
    }
    interface transaction_record_refund_params {
        date: number;
    }
    interface credit_note_record_refund_params {
        reason_code?: string;
    }
    interface credit_note_record_refund_params {
        create_reason_code?: string;
    }
    interface transaction_remove_payment_params {
        id: string;
    }
    interface credit_note_remove_credit_note_params {
        id: string;
    }
    interface billing_address_update_details_params {
        first_name?: string;
    }
    interface billing_address_update_details_params {
        last_name?: string;
    }
    interface billing_address_update_details_params {
        email?: string;
    }
    interface billing_address_update_details_params {
        company?: string;
    }
    interface billing_address_update_details_params {
        phone?: string;
    }
    interface billing_address_update_details_params {
        line1?: string;
    }
    interface billing_address_update_details_params {
        line2?: string;
    }
    interface billing_address_update_details_params {
        line3?: string;
    }
    interface billing_address_update_details_params {
        city?: string;
    }
    interface billing_address_update_details_params {
        state_code?: string;
    }
    interface billing_address_update_details_params {
        state?: string;
    }
    interface billing_address_update_details_params {
        zip?: string;
    }
    interface billing_address_update_details_params {
        country?: string;
    }
    interface billing_address_update_details_params {
        validation_status?: string;
    }
    interface shipping_address_update_details_params {
        first_name?: string;
    }
    interface shipping_address_update_details_params {
        last_name?: string;
    }
    interface shipping_address_update_details_params {
        email?: string;
    }
    interface shipping_address_update_details_params {
        company?: string;
    }
    interface shipping_address_update_details_params {
        phone?: string;
    }
    interface shipping_address_update_details_params {
        line1?: string;
    }
    interface shipping_address_update_details_params {
        line2?: string;
    }
    interface shipping_address_update_details_params {
        line3?: string;
    }
    interface shipping_address_update_details_params {
        city?: string;
    }
    interface shipping_address_update_details_params {
        state_code?: string;
    }
    interface shipping_address_update_details_params {
        state?: string;
    }
    interface shipping_address_update_details_params {
        zip?: string;
    }
    interface shipping_address_update_details_params {
        country?: string;
    }
    interface shipping_address_update_details_params {
        validation_status?: string;
    }
    interface statement_descriptor_update_details_params {
        descriptor?: string;
    }
}
