import { ListResult } from '../list_result';
import { RequestWrapper } from "../request_wrapper";
import { Model } from "./model";
import { filter } from "../filter";
export declare class Quote extends Model {
    id: string;
    name?: string;
    po_number?: string;
    customer_id: string;
    subscription_id?: string;
    invoice_id?: string;
    status: string;
    operation_type: string;
    vat_number?: string;
    price_type: string;
    valid_till: number;
    date: number;
    total_payable?: number;
    charge_on_acceptance?: number;
    sub_total: number;
    total?: number;
    credits_applied?: number;
    amount_paid?: number;
    amount_due?: number;
    version?: number;
    resource_version?: number;
    updated_at?: number;
    vat_number_prefix?: string;
    line_items?: Array<LineItem>;
    discounts?: Array<Discount>;
    line_item_discounts?: Array<LineItemDiscount>;
    taxes?: Array<Tax>;
    line_item_taxes?: Array<LineItemTax>;
    line_item_tiers?: Array<LineItemTier>;
    tax_category?: string;
    currency_code: string;
    notes?: any;
    shipping_address?: ShippingAddress;
    billing_address?: BillingAddress;
    contract_term_start?: number;
    contract_term_end?: number;
    contract_term_termination_fee?: number;
    business_entity_id?: string;
    deleted: boolean;
    total_contract_value?: number;
    total_discount?: number;
    static retrieve(quote_id: string, params?: any): RequestWrapper;
    static create_sub_for_customer_quote(customer_id: string, params?: _quote.create_sub_for_customer_quote_params): RequestWrapper;
    static edit_create_sub_for_customer_quote(quote_id: string, params?: _quote.edit_create_sub_for_customer_quote_params): RequestWrapper;
    static update_subscription_quote(params?: _quote.update_subscription_quote_params): RequestWrapper;
    static edit_update_subscription_quote(quote_id: string, params?: _quote.edit_update_subscription_quote_params): RequestWrapper;
    static create_for_onetime_charges(params?: _quote.create_for_onetime_charges_params): RequestWrapper;
    static edit_one_time_quote(quote_id: string, params?: _quote.edit_one_time_quote_params): RequestWrapper;
    static create_sub_items_for_customer_quote(customer_id: string, params?: _quote.create_sub_items_for_customer_quote_params): RequestWrapper;
    static edit_create_sub_customer_quote_for_items(quote_id: string, params?: _quote.edit_create_sub_customer_quote_for_items_params): RequestWrapper;
    static update_subscription_quote_for_items(params?: _quote.update_subscription_quote_for_items_params): RequestWrapper;
    static edit_update_subscription_quote_for_items(quote_id: string, params?: _quote.edit_update_subscription_quote_for_items_params): RequestWrapper;
    static create_for_charge_items_and_charges(params?: _quote.create_for_charge_items_and_charges_params): RequestWrapper;
    static edit_for_charge_items_and_charges(quote_id: string, params?: _quote.edit_for_charge_items_and_charges_params): RequestWrapper;
    static list(params?: _quote.quote_list_params): RequestWrapper<ListResult>;
    static quote_line_groups_for_quote(quote_id: string, params?: any): RequestWrapper<ListResult>;
    static convert(quote_id: string, params?: _quote.convert_params): RequestWrapper;
    static update_status(quote_id: string, params?: _quote.update_status_params): RequestWrapper;
    static extend_expiry_date(quote_id: string, params?: _quote.extend_expiry_date_params): RequestWrapper;
    static delete(quote_id: string, params?: _quote.delete_params): RequestWrapper;
    static pdf(quote_id: string, params?: _quote.pdf_params): RequestWrapper;
}
export declare class LineItem extends Model {
    id?: string;
    subscription_id?: string;
    date_from: number;
    date_to: number;
    unit_amount: number;
    quantity?: number;
    amount?: number;
    pricing_model?: string;
    is_taxed: boolean;
    tax_amount?: number;
    tax_rate?: number;
    unit_amount_in_decimal?: string;
    quantity_in_decimal?: string;
    amount_in_decimal?: string;
    discount_amount?: number;
    item_level_discount_amount?: number;
    metered?: boolean;
    is_percentage_pricing?: boolean;
    reference_line_item_id?: string;
    description: string;
    entity_description?: string;
    entity_type: string;
    tax_exempt_reason?: string;
    entity_id?: string;
    customer_id?: string;
}
export declare class Discount extends Model {
    amount: number;
    description?: string;
    entity_type: string;
    discount_type?: string;
    entity_id?: string;
    coupon_set_code?: string;
}
export declare class LineItemDiscount extends Model {
    line_item_id: string;
    discount_type: string;
    coupon_id?: string;
    entity_id?: string;
    discount_amount: number;
}
export declare class Tax extends Model {
    name: string;
    amount: number;
    description?: string;
}
export declare class LineItemTax extends Model {
    line_item_id?: string;
    tax_name: string;
    tax_rate: number;
    date_to?: number;
    date_from?: number;
    prorated_taxable_amount?: number;
    is_partial_tax_applied?: boolean;
    is_non_compliance_tax?: boolean;
    taxable_amount: number;
    tax_amount: number;
    tax_juris_type?: string;
    tax_juris_name?: string;
    tax_juris_code?: string;
    tax_amount_in_local_currency?: number;
    local_currency_code?: string;
}
export declare class LineItemTier extends Model {
    line_item_id?: string;
    starting_unit: number;
    ending_unit?: number;
    quantity_used: number;
    unit_amount: number;
    starting_unit_in_decimal?: string;
    ending_unit_in_decimal?: string;
    quantity_used_in_decimal?: string;
    unit_amount_in_decimal?: string;
    pricing_type?: string;
    package_size?: number;
}
export declare class ShippingAddress extends Model {
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
    index: number;
}
export declare class BillingAddress extends Model {
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
}
export declare namespace _quote {
    interface create_sub_for_customer_quote_params {
        name?: string;
        notes?: string;
        expires_at?: number;
        billing_cycles?: number;
        mandatory_addons_to_remove?: Array<string>;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        subscription?: subscription_create_sub_for_customer_quote_params;
        shipping_address?: shipping_address_create_sub_for_customer_quote_params;
        contract_term?: contract_term_create_sub_for_customer_quote_params;
        addons?: Array<addons_create_sub_for_customer_quote_params>;
        event_based_addons?: Array<event_based_addons_create_sub_for_customer_quote_params>;
    }
    interface edit_create_sub_for_customer_quote_params {
        notes?: string;
        expires_at?: number;
        billing_cycles?: number;
        mandatory_addons_to_remove?: Array<string>;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        subscription?: subscription_edit_create_sub_for_customer_quote_params;
        shipping_address?: shipping_address_edit_create_sub_for_customer_quote_params;
        contract_term?: contract_term_edit_create_sub_for_customer_quote_params;
        addons?: Array<addons_edit_create_sub_for_customer_quote_params>;
        event_based_addons?: Array<event_based_addons_edit_create_sub_for_customer_quote_params>;
    }
    interface update_subscription_quote_params {
        name?: string;
        notes?: string;
        expires_at?: number;
        replace_addon_list?: boolean;
        mandatory_addons_to_remove?: Array<string>;
        billing_cycles?: number;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        change_option?: string;
        changes_scheduled_at?: number;
        force_term_reset?: boolean;
        reactivate?: boolean;
        subscription?: subscription_update_subscription_quote_params;
        billing_address?: billing_address_update_subscription_quote_params;
        shipping_address?: shipping_address_update_subscription_quote_params;
        customer?: customer_update_subscription_quote_params;
        contract_term?: contract_term_update_subscription_quote_params;
        addons?: Array<addons_update_subscription_quote_params>;
        event_based_addons?: Array<event_based_addons_update_subscription_quote_params>;
    }
    interface edit_update_subscription_quote_params {
        notes?: string;
        expires_at?: number;
        replace_addon_list?: boolean;
        mandatory_addons_to_remove?: Array<string>;
        billing_cycles?: number;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        change_option?: string;
        changes_scheduled_at?: number;
        force_term_reset?: boolean;
        reactivate?: boolean;
        subscription?: subscription_edit_update_subscription_quote_params;
        billing_address?: billing_address_edit_update_subscription_quote_params;
        shipping_address?: shipping_address_edit_update_subscription_quote_params;
        customer?: customer_edit_update_subscription_quote_params;
        contract_term?: contract_term_edit_update_subscription_quote_params;
        addons?: Array<addons_edit_update_subscription_quote_params>;
        event_based_addons?: Array<event_based_addons_edit_update_subscription_quote_params>;
    }
    interface create_for_onetime_charges_params {
        name?: string;
        customer_id: string;
        po_number?: string;
        notes?: string;
        expires_at?: number;
        currency_code?: string;
        coupon?: string;
        coupon_ids?: Array<string>;
        shipping_address?: shipping_address_create_for_onetime_charges_params;
        addons?: Array<addons_create_for_onetime_charges_params>;
        charges?: Array<charges_create_for_onetime_charges_params>;
        tax_providers_fields?: Array<tax_providers_fields_create_for_onetime_charges_params>;
    }
    interface edit_one_time_quote_params {
        po_number?: string;
        notes?: string;
        expires_at?: number;
        currency_code?: string;
        coupon?: string;
        coupon_ids?: Array<string>;
        shipping_address?: shipping_address_edit_one_time_quote_params;
        addons?: Array<addons_edit_one_time_quote_params>;
        charges?: Array<charges_edit_one_time_quote_params>;
        tax_providers_fields?: Array<tax_providers_fields_edit_one_time_quote_params>;
    }
    interface create_sub_items_for_customer_quote_params {
        name?: string;
        notes?: string;
        expires_at?: number;
        billing_cycles?: number;
        mandatory_items_to_remove?: Array<string>;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        billing_start_option?: string;
        net_term_days?: number;
        subscription?: subscription_create_sub_items_for_customer_quote_params;
        shipping_address?: shipping_address_create_sub_items_for_customer_quote_params;
        contract_term?: contract_term_create_sub_items_for_customer_quote_params;
        billing_address?: billing_address_create_sub_items_for_customer_quote_params;
        subscription_items?: Array<subscription_items_create_sub_items_for_customer_quote_params>;
        discounts?: Array<discounts_create_sub_items_for_customer_quote_params>;
        item_tiers?: Array<item_tiers_create_sub_items_for_customer_quote_params>;
        coupons?: Array<coupons_create_sub_items_for_customer_quote_params>;
    }
    interface edit_create_sub_customer_quote_for_items_params {
        notes?: string;
        expires_at?: number;
        billing_cycles?: number;
        mandatory_items_to_remove?: Array<string>;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        billing_start_option?: string;
        net_term_days?: number;
        subscription?: subscription_edit_create_sub_customer_quote_for_items_params;
        shipping_address?: shipping_address_edit_create_sub_customer_quote_for_items_params;
        contract_term?: contract_term_edit_create_sub_customer_quote_for_items_params;
        billing_address?: billing_address_edit_create_sub_customer_quote_for_items_params;
        subscription_items?: Array<subscription_items_edit_create_sub_customer_quote_for_items_params>;
        discounts?: Array<discounts_edit_create_sub_customer_quote_for_items_params>;
        item_tiers?: Array<item_tiers_edit_create_sub_customer_quote_for_items_params>;
        coupons?: Array<coupons_edit_create_sub_customer_quote_for_items_params>;
    }
    interface update_subscription_quote_for_items_params {
        name?: string;
        notes?: string;
        expires_at?: number;
        mandatory_items_to_remove?: Array<string>;
        replace_items_list?: boolean;
        billing_cycles?: number;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        change_option?: string;
        changes_scheduled_at?: number;
        force_term_reset?: boolean;
        reactivate?: boolean;
        net_term_days?: number;
        subscription?: subscription_update_subscription_quote_for_items_params;
        billing_address?: billing_address_update_subscription_quote_for_items_params;
        shipping_address?: shipping_address_update_subscription_quote_for_items_params;
        customer?: customer_update_subscription_quote_for_items_params;
        contract_term?: contract_term_update_subscription_quote_for_items_params;
        subscription_items?: Array<subscription_items_update_subscription_quote_for_items_params>;
        discounts?: Array<discounts_update_subscription_quote_for_items_params>;
        item_tiers?: Array<item_tiers_update_subscription_quote_for_items_params>;
        coupons?: Array<coupons_update_subscription_quote_for_items_params>;
    }
    interface edit_update_subscription_quote_for_items_params {
        notes?: string;
        expires_at?: number;
        mandatory_items_to_remove?: Array<string>;
        replace_items_list?: boolean;
        billing_cycles?: number;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        change_option?: string;
        changes_scheduled_at?: number;
        force_term_reset?: boolean;
        reactivate?: boolean;
        net_term_days?: number;
        subscription?: subscription_edit_update_subscription_quote_for_items_params;
        billing_address?: billing_address_edit_update_subscription_quote_for_items_params;
        shipping_address?: shipping_address_edit_update_subscription_quote_for_items_params;
        customer?: customer_edit_update_subscription_quote_for_items_params;
        contract_term?: contract_term_edit_update_subscription_quote_for_items_params;
        subscription_items?: Array<subscription_items_edit_update_subscription_quote_for_items_params>;
        discounts?: Array<discounts_edit_update_subscription_quote_for_items_params>;
        item_tiers?: Array<item_tiers_edit_update_subscription_quote_for_items_params>;
        coupons?: Array<coupons_edit_update_subscription_quote_for_items_params>;
    }
    interface create_for_charge_items_and_charges_params {
        name?: string;
        customer_id: string;
        po_number?: string;
        notes?: string;
        expires_at?: number;
        currency_code?: string;
        coupon?: string;
        coupon_ids?: Array<string>;
        billing_address?: billing_address_create_for_charge_items_and_charges_params;
        shipping_address?: shipping_address_create_for_charge_items_and_charges_params;
        item_prices?: Array<item_prices_create_for_charge_items_and_charges_params>;
        item_tiers?: Array<item_tiers_create_for_charge_items_and_charges_params>;
        charges?: Array<charges_create_for_charge_items_and_charges_params>;
        discounts?: Array<discounts_create_for_charge_items_and_charges_params>;
        tax_providers_fields?: Array<tax_providers_fields_create_for_charge_items_and_charges_params>;
    }
    interface edit_for_charge_items_and_charges_params {
        po_number?: string;
        notes?: string;
        expires_at?: number;
        currency_code?: string;
        coupon?: string;
        coupon_ids?: Array<string>;
        billing_address?: billing_address_edit_for_charge_items_and_charges_params;
        shipping_address?: shipping_address_edit_for_charge_items_and_charges_params;
        item_prices?: Array<item_prices_edit_for_charge_items_and_charges_params>;
        item_tiers?: Array<item_tiers_edit_for_charge_items_and_charges_params>;
        charges?: Array<charges_edit_for_charge_items_and_charges_params>;
        discounts?: Array<discounts_edit_for_charge_items_and_charges_params>;
        tax_providers_fields?: Array<tax_providers_fields_edit_for_charge_items_and_charges_params>;
    }
    interface quote_list_params {
        limit?: number;
        offset?: string;
        include_deleted?: boolean;
        id?: filter._string;
        customer_id?: filter._string;
        subscription_id?: filter._string;
        status?: filter._enum;
        date?: filter._timestamp;
        updated_at?: filter._timestamp;
        "sort_by[asc]"?: string;
        "sort_by[desc]"?: string;
    }
    interface convert_params {
        invoice_date?: number;
        invoice_immediately?: boolean;
        create_pending_invoices?: boolean;
        first_invoice_pending?: boolean;
        subscription?: subscription_convert_params;
    }
    interface update_status_params {
        status: string;
        comment?: string;
    }
    interface extend_expiry_date_params {
        valid_till: number;
    }
    interface delete_params {
        comment?: string;
    }
    interface pdf_params {
        consolidated_view?: boolean;
        disposition_type?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        po_number?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        plan_id: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        plan_quantity?: number;
    }
    interface subscription_create_sub_for_customer_quote_params {
        plan_quantity_in_decimal?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        plan_unit_price?: number;
    }
    interface subscription_create_sub_for_customer_quote_params {
        plan_unit_price_in_decimal?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        setup_fee?: number;
    }
    interface subscription_create_sub_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_create_sub_for_customer_quote_params {
        start_date?: number;
    }
    interface subscription_create_sub_for_customer_quote_params {
        offline_payment_method?: string;
    }
    interface subscription_create_sub_for_customer_quote_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        first_name?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        last_name?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        email?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        company?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        phone?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        line1?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        line2?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        line3?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        city?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        state_code?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        state?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        zip?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        country?: string;
    }
    interface shipping_address_create_sub_for_customer_quote_params {
        validation_status?: string;
    }
    interface contract_term_create_sub_for_customer_quote_params {
        action_at_term_end?: string;
    }
    interface contract_term_create_sub_for_customer_quote_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface addons_create_sub_for_customer_quote_params {
        quantity?: number;
    }
    interface addons_create_sub_for_customer_quote_params {
        quantity_in_decimal?: string;
    }
    interface addons_create_sub_for_customer_quote_params {
        unit_price?: number;
    }
    interface addons_create_sub_for_customer_quote_params {
        unit_price_in_decimal?: string;
    }
    interface addons_create_sub_for_customer_quote_params {
        billing_cycles?: number;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        quantity?: number;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        unit_price?: number;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        on_event?: string;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        charge_once?: boolean;
    }
    interface event_based_addons_create_sub_for_customer_quote_params {
        charge_on?: string;
    }
    interface addons_create_sub_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        po_number?: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        plan_id: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        plan_quantity?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        plan_quantity_in_decimal?: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        plan_unit_price?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        plan_unit_price_in_decimal?: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        setup_fee?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        start_date?: number;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        offline_payment_method?: string;
    }
    interface subscription_edit_create_sub_for_customer_quote_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        first_name?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        last_name?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        email?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        company?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        phone?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        line1?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        line2?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        line3?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        city?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        state_code?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        state?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        zip?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        country?: string;
    }
    interface shipping_address_edit_create_sub_for_customer_quote_params {
        validation_status?: string;
    }
    interface contract_term_edit_create_sub_for_customer_quote_params {
        action_at_term_end?: string;
    }
    interface contract_term_edit_create_sub_for_customer_quote_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        quantity?: number;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        quantity_in_decimal?: string;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        unit_price?: number;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        unit_price_in_decimal?: string;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        billing_cycles?: number;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        id?: string;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        quantity?: number;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        unit_price?: number;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        on_event?: string;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        charge_once?: boolean;
    }
    interface event_based_addons_edit_create_sub_for_customer_quote_params {
        charge_on?: string;
    }
    interface addons_edit_create_sub_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_update_subscription_quote_params {
        id: string;
    }
    interface subscription_update_subscription_quote_params {
        plan_id?: string;
    }
    interface subscription_update_subscription_quote_params {
        plan_quantity?: number;
    }
    interface subscription_update_subscription_quote_params {
        plan_unit_price?: number;
    }
    interface subscription_update_subscription_quote_params {
        setup_fee?: number;
    }
    interface subscription_update_subscription_quote_params {
        plan_quantity_in_decimal?: string;
    }
    interface subscription_update_subscription_quote_params {
        plan_unit_price_in_decimal?: string;
    }
    interface subscription_update_subscription_quote_params {
        start_date?: number;
    }
    interface subscription_update_subscription_quote_params {
        trial_end?: number;
    }
    interface subscription_update_subscription_quote_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
    }
    interface subscription_update_subscription_quote_params {
        auto_collection?: string;
    }
    interface subscription_update_subscription_quote_params {
        offline_payment_method?: string;
    }
    interface subscription_update_subscription_quote_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface billing_address_update_subscription_quote_params {
        first_name?: string;
    }
    interface billing_address_update_subscription_quote_params {
        last_name?: string;
    }
    interface billing_address_update_subscription_quote_params {
        email?: string;
    }
    interface billing_address_update_subscription_quote_params {
        company?: string;
    }
    interface billing_address_update_subscription_quote_params {
        phone?: string;
    }
    interface billing_address_update_subscription_quote_params {
        line1?: string;
    }
    interface billing_address_update_subscription_quote_params {
        line2?: string;
    }
    interface billing_address_update_subscription_quote_params {
        line3?: string;
    }
    interface billing_address_update_subscription_quote_params {
        city?: string;
    }
    interface billing_address_update_subscription_quote_params {
        state_code?: string;
    }
    interface billing_address_update_subscription_quote_params {
        state?: string;
    }
    interface billing_address_update_subscription_quote_params {
        zip?: string;
    }
    interface billing_address_update_subscription_quote_params {
        country?: string;
    }
    interface billing_address_update_subscription_quote_params {
        validation_status?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        first_name?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        last_name?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        email?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        company?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        phone?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        line1?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        line2?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        line3?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        city?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        state_code?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        state?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        zip?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        country?: string;
    }
    interface shipping_address_update_subscription_quote_params {
        validation_status?: string;
    }
    interface customer_update_subscription_quote_params {
        vat_number?: string;
    }
    interface customer_update_subscription_quote_params {
        vat_number_prefix?: string;
    }
    interface customer_update_subscription_quote_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_update_subscription_quote_params {
        action_at_term_end?: string;
    }
    interface contract_term_update_subscription_quote_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_update_subscription_quote_params {
        id?: string;
    }
    interface addons_update_subscription_quote_params {
        quantity?: number;
    }
    interface addons_update_subscription_quote_params {
        unit_price?: number;
    }
    interface addons_update_subscription_quote_params {
        billing_cycles?: number;
    }
    interface addons_update_subscription_quote_params {
        quantity_in_decimal?: string;
    }
    interface addons_update_subscription_quote_params {
        unit_price_in_decimal?: string;
    }
    interface addons_update_subscription_quote_params {
        trial_end?: number;
    }
    interface event_based_addons_update_subscription_quote_params {
        id?: string;
    }
    interface event_based_addons_update_subscription_quote_params {
        quantity?: number;
    }
    interface event_based_addons_update_subscription_quote_params {
        unit_price?: number;
    }
    interface event_based_addons_update_subscription_quote_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_update_subscription_quote_params {
        charge_on?: string;
    }
    interface event_based_addons_update_subscription_quote_params {
        on_event?: string;
    }
    interface event_based_addons_update_subscription_quote_params {
        charge_once?: boolean;
    }
    interface event_based_addons_update_subscription_quote_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_update_subscription_quote_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        plan_id?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        plan_quantity?: number;
    }
    interface subscription_edit_update_subscription_quote_params {
        plan_unit_price?: number;
    }
    interface subscription_edit_update_subscription_quote_params {
        setup_fee?: number;
    }
    interface subscription_edit_update_subscription_quote_params {
        plan_quantity_in_decimal?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        plan_unit_price_in_decimal?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        start_date?: number;
    }
    interface subscription_edit_update_subscription_quote_params {
        trial_end?: number;
    }
    interface subscription_edit_update_subscription_quote_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        auto_collection?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        offline_payment_method?: string;
    }
    interface subscription_edit_update_subscription_quote_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface billing_address_edit_update_subscription_quote_params {
        first_name?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        last_name?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        email?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        company?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        phone?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        line1?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        line2?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        line3?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        city?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        state_code?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        state?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        zip?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        country?: string;
    }
    interface billing_address_edit_update_subscription_quote_params {
        validation_status?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        first_name?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        last_name?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        email?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        company?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        phone?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        line1?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        line2?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        line3?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        city?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        state_code?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        state?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        zip?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        country?: string;
    }
    interface shipping_address_edit_update_subscription_quote_params {
        validation_status?: string;
    }
    interface customer_edit_update_subscription_quote_params {
        vat_number?: string;
    }
    interface customer_edit_update_subscription_quote_params {
        vat_number_prefix?: string;
    }
    interface customer_edit_update_subscription_quote_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_edit_update_subscription_quote_params {
        action_at_term_end?: string;
    }
    interface contract_term_edit_update_subscription_quote_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_edit_update_subscription_quote_params {
        id?: string;
    }
    interface addons_edit_update_subscription_quote_params {
        quantity?: number;
    }
    interface addons_edit_update_subscription_quote_params {
        unit_price?: number;
    }
    interface addons_edit_update_subscription_quote_params {
        billing_cycles?: number;
    }
    interface addons_edit_update_subscription_quote_params {
        quantity_in_decimal?: string;
    }
    interface addons_edit_update_subscription_quote_params {
        unit_price_in_decimal?: string;
    }
    interface addons_edit_update_subscription_quote_params {
        trial_end?: number;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        id?: string;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        quantity?: number;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        unit_price?: number;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        charge_on?: string;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        on_event?: string;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        charge_once?: boolean;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_edit_update_subscription_quote_params {
        unit_price_in_decimal?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        first_name?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        last_name?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        email?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        company?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        phone?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        line1?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        line2?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        line3?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        city?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        state_code?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        state?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        zip?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        country?: string;
    }
    interface shipping_address_create_for_onetime_charges_params {
        validation_status?: string;
    }
    interface addons_create_for_onetime_charges_params {
        id?: string;
    }
    interface addons_create_for_onetime_charges_params {
        quantity?: number;
    }
    interface addons_create_for_onetime_charges_params {
        quantity_in_decimal?: string;
    }
    interface addons_create_for_onetime_charges_params {
        unit_price?: number;
    }
    interface addons_create_for_onetime_charges_params {
        unit_price_in_decimal?: string;
    }
    interface addons_create_for_onetime_charges_params {
        service_period?: number;
    }
    interface charges_create_for_onetime_charges_params {
        amount?: number;
    }
    interface charges_create_for_onetime_charges_params {
        amount_in_decimal?: string;
    }
    interface charges_create_for_onetime_charges_params {
        description?: string;
    }
    interface charges_create_for_onetime_charges_params {
        avalara_sale_type?: string;
    }
    interface charges_create_for_onetime_charges_params {
        avalara_transaction_type?: number;
    }
    interface charges_create_for_onetime_charges_params {
        avalara_service_type?: number;
    }
    interface charges_create_for_onetime_charges_params {
        service_period?: number;
    }
    interface tax_providers_fields_create_for_onetime_charges_params {
        provider_name?: string;
    }
    interface tax_providers_fields_create_for_onetime_charges_params {
        field_id?: string;
    }
    interface tax_providers_fields_create_for_onetime_charges_params {
        field_value?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        first_name?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        last_name?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        email?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        company?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        phone?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        line1?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        line2?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        line3?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        city?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        state_code?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        state?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        zip?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        country?: string;
    }
    interface shipping_address_edit_one_time_quote_params {
        validation_status?: string;
    }
    interface addons_edit_one_time_quote_params {
        id?: string;
    }
    interface addons_edit_one_time_quote_params {
        quantity?: number;
    }
    interface addons_edit_one_time_quote_params {
        quantity_in_decimal?: string;
    }
    interface addons_edit_one_time_quote_params {
        unit_price?: number;
    }
    interface addons_edit_one_time_quote_params {
        unit_price_in_decimal?: string;
    }
    interface addons_edit_one_time_quote_params {
        service_period?: number;
    }
    interface charges_edit_one_time_quote_params {
        amount?: number;
    }
    interface charges_edit_one_time_quote_params {
        amount_in_decimal?: string;
    }
    interface charges_edit_one_time_quote_params {
        description?: string;
    }
    interface charges_edit_one_time_quote_params {
        avalara_sale_type?: string;
    }
    interface charges_edit_one_time_quote_params {
        avalara_transaction_type?: number;
    }
    interface charges_edit_one_time_quote_params {
        avalara_service_type?: number;
    }
    interface charges_edit_one_time_quote_params {
        service_period?: number;
    }
    interface tax_providers_fields_edit_one_time_quote_params {
        provider_name?: string;
    }
    interface tax_providers_fields_edit_one_time_quote_params {
        field_id?: string;
    }
    interface tax_providers_fields_edit_one_time_quote_params {
        field_value?: string;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        id?: string;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        po_number?: string;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        start_date?: number;
    }
    interface subscription_create_sub_items_for_customer_quote_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        first_name?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        last_name?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        email?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        company?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        phone?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        line1?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        line2?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        line3?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        city?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        state_code?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        state?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        zip?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        country?: string;
    }
    interface shipping_address_create_sub_items_for_customer_quote_params {
        validation_status?: string;
    }
    interface contract_term_create_sub_items_for_customer_quote_params {
        action_at_term_end?: string;
    }
    interface contract_term_create_sub_items_for_customer_quote_params {
        cancellation_cutoff_period?: number;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        first_name?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        last_name?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        email?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        company?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        phone?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        line1?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        line2?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        line3?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        city?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        state_code?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        state?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        zip?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        country?: string;
    }
    interface billing_address_create_sub_items_for_customer_quote_params {
        validation_status?: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        item_price_id: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        quantity?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        unit_price?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        billing_cycles?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        trial_end?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        service_period_days?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        charge_on_event?: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        charge_once?: boolean;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        apply_on?: string;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        duration_type: string;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        percentage?: number;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        amount?: number;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        period?: number;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        period_unit?: string;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        included_in_mrr?: boolean;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        item_price_id?: string;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        charge_on_option?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        item_price_id?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        starting_unit?: number;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        ending_unit?: number;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        price?: number;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        price_in_decimal?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        pricing_type?: string;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        package_size?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        start_date?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        end_date?: number;
    }
    interface subscription_items_create_sub_items_for_customer_quote_params {
        ramp_tier_id?: string;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        start_date?: number;
    }
    interface discounts_create_sub_items_for_customer_quote_params {
        end_date?: number;
    }
    interface item_tiers_create_sub_items_for_customer_quote_params {
        ramp_tier_id?: string;
    }
    interface coupons_create_sub_items_for_customer_quote_params {
        id?: string;
    }
    interface coupons_create_sub_items_for_customer_quote_params {
        start_date?: number;
    }
    interface coupons_create_sub_items_for_customer_quote_params {
        end_date?: number;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        id?: string;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        po_number?: string;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_edit_create_sub_customer_quote_for_items_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        first_name?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        last_name?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        email?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        company?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        phone?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        line1?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        line2?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        line3?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        city?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        state_code?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        state?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        zip?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        country?: string;
    }
    interface shipping_address_edit_create_sub_customer_quote_for_items_params {
        validation_status?: string;
    }
    interface contract_term_edit_create_sub_customer_quote_for_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_edit_create_sub_customer_quote_for_items_params {
        cancellation_cutoff_period?: number;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        first_name?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        last_name?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        email?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        company?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        phone?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        line1?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        line2?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        line3?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        city?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        state_code?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        state?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        zip?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        country?: string;
    }
    interface billing_address_edit_create_sub_customer_quote_for_items_params {
        validation_status?: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        item_price_id: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        quantity?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        service_period_days?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        apply_on?: string;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        duration_type: string;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        percentage?: number;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        amount?: number;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        period?: number;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        period_unit?: string;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        item_price_id?: string;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        charge_on_option?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        item_price_id?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        starting_unit?: number;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        ending_unit?: number;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        price?: number;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        pricing_type?: string;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        package_size?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        end_date?: number;
    }
    interface subscription_items_edit_create_sub_customer_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        start_date?: number;
    }
    interface discounts_edit_create_sub_customer_quote_for_items_params {
        end_date?: number;
    }
    interface item_tiers_edit_create_sub_customer_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface coupons_edit_create_sub_customer_quote_for_items_params {
        id?: string;
    }
    interface coupons_edit_create_sub_customer_quote_for_items_params {
        start_date?: number;
    }
    interface coupons_edit_create_sub_customer_quote_for_items_params {
        end_date?: number;
    }
    interface subscription_update_subscription_quote_for_items_params {
        id: string;
    }
    interface subscription_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
    }
    interface subscription_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_update_subscription_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
    }
    interface subscription_update_subscription_quote_for_items_params {
        auto_collection?: string;
    }
    interface subscription_update_subscription_quote_for_items_params {
        offline_payment_method?: string;
    }
    interface subscription_update_subscription_quote_for_items_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        first_name?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        last_name?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        email?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        company?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        phone?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        line1?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        line2?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        line3?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        city?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        state_code?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        state?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        zip?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        country?: string;
    }
    interface billing_address_update_subscription_quote_for_items_params {
        validation_status?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        first_name?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        last_name?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        email?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        company?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        phone?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        line1?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        line2?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        line3?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        city?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        state_code?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        state?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        zip?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        country?: string;
    }
    interface shipping_address_update_subscription_quote_for_items_params {
        validation_status?: string;
    }
    interface customer_update_subscription_quote_for_items_params {
        vat_number?: string;
    }
    interface customer_update_subscription_quote_for_items_params {
        vat_number_prefix?: string;
    }
    interface customer_update_subscription_quote_for_items_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_update_subscription_quote_for_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_update_subscription_quote_for_items_params {
        cancellation_cutoff_period?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        item_price_id: string;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        quantity?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        service_period_days?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        charge_on_option?: string;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        apply_on?: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        duration_type: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        percentage?: number;
    }
    interface discounts_update_subscription_quote_for_items_params {
        amount?: number;
    }
    interface discounts_update_subscription_quote_for_items_params {
        period?: number;
    }
    interface discounts_update_subscription_quote_for_items_params {
        period_unit?: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_update_subscription_quote_for_items_params {
        item_price_id?: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        operation_type: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        id?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        item_price_id?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        starting_unit?: number;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        ending_unit?: number;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        price?: number;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        pricing_type?: string;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        package_size?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface subscription_items_update_subscription_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface discounts_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface discounts_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface item_tiers_update_subscription_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface coupons_update_subscription_quote_for_items_params {
        id?: string;
    }
    interface coupons_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface coupons_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        auto_collection?: string;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        offline_payment_method?: string;
    }
    interface subscription_edit_update_subscription_quote_for_items_params {
        contract_term_billing_cycle_on_renewal?: number;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        first_name?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        last_name?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        email?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        company?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        phone?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        line1?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        line2?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        line3?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        city?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        state_code?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        state?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        zip?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        country?: string;
    }
    interface billing_address_edit_update_subscription_quote_for_items_params {
        validation_status?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        first_name?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        last_name?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        email?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        company?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        phone?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        line1?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        line2?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        line3?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        city?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        state_code?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        state?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        zip?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        country?: string;
    }
    interface shipping_address_edit_update_subscription_quote_for_items_params {
        validation_status?: string;
    }
    interface customer_edit_update_subscription_quote_for_items_params {
        vat_number?: string;
    }
    interface customer_edit_update_subscription_quote_for_items_params {
        vat_number_prefix?: string;
    }
    interface customer_edit_update_subscription_quote_for_items_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_edit_update_subscription_quote_for_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_edit_update_subscription_quote_for_items_params {
        cancellation_cutoff_period?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        item_price_id: string;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        quantity?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        trial_end?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        service_period_days?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        charge_on_option?: string;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        apply_on?: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        duration_type: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        percentage?: number;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        amount?: number;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        period?: number;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        period_unit?: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        item_price_id?: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        operation_type: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        id?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        item_price_id?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        starting_unit?: number;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        ending_unit?: number;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        price?: number;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        pricing_type?: string;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        package_size?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface subscription_items_edit_update_subscription_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface discounts_edit_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface item_tiers_edit_update_subscription_quote_for_items_params {
        ramp_tier_id?: string;
    }
    interface coupons_edit_update_subscription_quote_for_items_params {
        id?: string;
    }
    interface coupons_edit_update_subscription_quote_for_items_params {
        start_date?: number;
    }
    interface coupons_edit_update_subscription_quote_for_items_params {
        end_date?: number;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        email?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        company?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        line1?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        line2?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        line3?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        city?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        state_code?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        state?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        zip?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        country?: string;
    }
    interface billing_address_create_for_charge_items_and_charges_params {
        validation_status?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        email?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        company?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line1?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line2?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        line3?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        city?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        state_code?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        state?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        zip?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        country?: string;
    }
    interface shipping_address_create_for_charge_items_and_charges_params {
        validation_status?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        quantity?: number;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        quantity_in_decimal?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        unit_price?: number;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        unit_price_in_decimal?: string;
    }
    interface item_prices_create_for_charge_items_and_charges_params {
        service_period_days?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        starting_unit?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        ending_unit?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        price?: number;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        price_in_decimal?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        pricing_type?: string;
    }
    interface item_tiers_create_for_charge_items_and_charges_params {
        package_size?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        amount_in_decimal?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        description?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_sale_type?: string;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_transaction_type?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        avalara_service_type?: number;
    }
    interface charges_create_for_charge_items_and_charges_params {
        service_period?: number;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        percentage?: number;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        apply_on: string;
    }
    interface discounts_create_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        provider_name?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        field_id?: string;
    }
    interface tax_providers_fields_create_for_charge_items_and_charges_params {
        field_value?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        email?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        company?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        line1?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        line2?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        line3?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        city?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        state_code?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        state?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        zip?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        country?: string;
    }
    interface billing_address_edit_for_charge_items_and_charges_params {
        validation_status?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        first_name?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        last_name?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        email?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        company?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        phone?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        line1?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        line2?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        line3?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        city?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        state_code?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        state?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        zip?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        country?: string;
    }
    interface shipping_address_edit_for_charge_items_and_charges_params {
        validation_status?: string;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        quantity?: number;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        quantity_in_decimal?: string;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        unit_price?: number;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        unit_price_in_decimal?: string;
    }
    interface item_prices_edit_for_charge_items_and_charges_params {
        service_period_days?: number;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        starting_unit?: number;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        ending_unit?: number;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        price?: number;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        price_in_decimal?: string;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        pricing_type?: string;
    }
    interface item_tiers_edit_for_charge_items_and_charges_params {
        package_size?: number;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        amount_in_decimal?: string;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        description?: string;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        avalara_sale_type?: string;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        avalara_transaction_type?: number;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        avalara_service_type?: number;
    }
    interface charges_edit_for_charge_items_and_charges_params {
        service_period?: number;
    }
    interface discounts_edit_for_charge_items_and_charges_params {
        percentage?: number;
    }
    interface discounts_edit_for_charge_items_and_charges_params {
        amount?: number;
    }
    interface discounts_edit_for_charge_items_and_charges_params {
        apply_on: string;
    }
    interface discounts_edit_for_charge_items_and_charges_params {
        item_price_id?: string;
    }
    interface tax_providers_fields_edit_for_charge_items_and_charges_params {
        provider_name?: string;
    }
    interface tax_providers_fields_edit_for_charge_items_and_charges_params {
        field_id?: string;
    }
    interface tax_providers_fields_edit_for_charge_items_and_charges_params {
        field_value?: string;
    }
    interface subscription_convert_params {
        id?: string;
    }
    interface subscription_convert_params {
        auto_collection?: string;
    }
    interface subscription_convert_params {
        po_number?: string;
    }
    interface subscription_convert_params {
        auto_close_invoices?: boolean;
    }
}
