import { ListResult } from '../list_result';
import { RequestWrapper } from "../request_wrapper";
import { Model } from "./model";
import { filter } from "../filter";
export declare class Subscription extends Model {
    id: string;
    currency_code: string;
    plan_id: string;
    plan_quantity: number;
    plan_unit_price?: number;
    setup_fee?: number;
    billing_period?: number;
    billing_period_unit?: string;
    start_date?: number;
    trial_end?: number;
    remaining_billing_cycles?: number;
    po_number?: string;
    auto_collection?: string;
    plan_quantity_in_decimal?: string;
    plan_unit_price_in_decimal?: string;
    customer_id: string;
    plan_amount?: number;
    plan_free_quantity?: number;
    status: string;
    trial_start?: number;
    trial_end_action?: string;
    current_term_start?: number;
    current_term_end?: number;
    next_billing_at?: number;
    created_at?: number;
    started_at?: number;
    activated_at?: number;
    gift_id?: string;
    contract_term_billing_cycle_on_renewal?: number;
    override_relationship?: boolean;
    pause_date?: number;
    resume_date?: number;
    cancelled_at?: number;
    cancel_reason?: string;
    affiliate_token?: string;
    created_from_ip?: string;
    resource_version?: number;
    updated_at?: number;
    has_scheduled_advance_invoices: boolean;
    has_scheduled_changes: boolean;
    payment_source_id?: string;
    plan_free_quantity_in_decimal?: string;
    plan_amount_in_decimal?: string;
    cancel_schedule_created_at?: number;
    offline_payment_method?: string;
    channel?: string;
    net_term_days?: number;
    active_id?: string;
    subscription_items?: Array<SubscriptionItem>;
    item_tiers?: Array<ItemTier>;
    charged_items?: Array<ChargedItem>;
    due_invoices_count?: number;
    due_since?: number;
    total_dues?: number;
    mrr?: number;
    arr?: number;
    exchange_rate?: number;
    base_currency_code?: string;
    addons?: Array<Addon>;
    event_based_addons?: Array<EventBasedAddon>;
    charged_event_based_addons?: Array<ChargedEventBasedAddon>;
    coupon?: string;
    coupons?: Array<Coupon>;
    shipping_address?: ShippingAddress;
    referral_info?: ReferralInfo;
    billing_override?: BillingOverride;
    invoice_notes?: string;
    meta_data?: any;
    deleted: boolean;
    changes_scheduled_at?: number;
    contract_term?: ContractTerm;
    cancel_reason_code?: string;
    free_period?: number;
    free_period_unit?: string;
    create_pending_invoices?: boolean;
    auto_close_invoices?: boolean;
    discounts?: Array<Discount>;
    business_entity_id?: string;
    /**
    * @deprecated use meta_data instead
    */
    metadata?: any;
    static create(params?: _subscription.create_params): RequestWrapper;
    static create_for_customer(customer_id: string, params?: _subscription.create_for_customer_params): RequestWrapper;
    static create_with_items(customer_id: string, params?: _subscription.create_with_items_params): RequestWrapper;
    static list(params?: _subscription.subscription_list_params): RequestWrapper<ListResult>;
    static subscriptions_for_customer(customer_id: string, params?: any): RequestWrapper<ListResult>;
    static contract_terms_for_subscription(subscription_id: string, params?: _subscription.subscription_contract_terms_for_subscription_params): RequestWrapper<ListResult>;
    static list_discounts(subscription_id: string, params?: any): RequestWrapper<ListResult>;
    static retrieve(subscription_id: string, params?: any): RequestWrapper;
    static retrieve_with_scheduled_changes(subscription_id: string, params?: any): RequestWrapper;
    static remove_scheduled_changes(subscription_id: string, params?: any): RequestWrapper;
    static remove_scheduled_cancellation(subscription_id: string, params?: _subscription.remove_scheduled_cancellation_params): RequestWrapper;
    static remove_coupons(subscription_id: string, params?: _subscription.remove_coupons_params): RequestWrapper;
    static update(subscription_id: string, params?: _subscription.update_params): RequestWrapper;
    static update_for_items(subscription_id: string, params?: _subscription.update_for_items_params): RequestWrapper;
    static change_term_end(subscription_id: string, params?: _subscription.change_term_end_params): RequestWrapper;
    static reactivate(subscription_id: string, params?: _subscription.reactivate_params): RequestWrapper;
    static add_charge_at_term_end(subscription_id: string, params?: _subscription.add_charge_at_term_end_params): RequestWrapper;
    static charge_addon_at_term_end(subscription_id: string, params?: _subscription.charge_addon_at_term_end_params): RequestWrapper;
    static charge_future_renewals(subscription_id: string, params?: _subscription.charge_future_renewals_params): RequestWrapper;
    static edit_advance_invoice_schedule(subscription_id: string, params?: _subscription.edit_advance_invoice_schedule_params): RequestWrapper;
    static retrieve_advance_invoice_schedule(subscription_id: string, params?: any): RequestWrapper;
    static remove_advance_invoice_schedule(subscription_id: string, params?: _subscription.remove_advance_invoice_schedule_params): RequestWrapper;
    static regenerate_invoice(subscription_id: string, params?: _subscription.regenerate_invoice_params): RequestWrapper;
    static import_subscription(params?: _subscription.import_subscription_params): RequestWrapper;
    static import_for_customer(customer_id: string, params?: _subscription.import_for_customer_params): RequestWrapper;
    static import_contract_term(subscription_id: string, params?: _subscription.import_contract_term_params): RequestWrapper;
    static import_unbilled_charges(subscription_id: string, params?: _subscription.import_unbilled_charges_params): RequestWrapper;
    static import_for_items(customer_id: string, params?: _subscription.import_for_items_params): RequestWrapper;
    static override_billing_profile(subscription_id: string, params?: _subscription.override_billing_profile_params): RequestWrapper;
    static delete(subscription_id: string, params?: any): RequestWrapper;
    static pause(subscription_id: string, params?: _subscription.pause_params): RequestWrapper;
    static cancel(subscription_id: string, params?: _subscription.cancel_params): RequestWrapper;
    static cancel_for_items(subscription_id: string, params?: _subscription.cancel_for_items_params): RequestWrapper;
    static resume(subscription_id: string, params?: _subscription.resume_params): RequestWrapper;
    static remove_scheduled_pause(subscription_id: string, params?: any): RequestWrapper;
    static remove_scheduled_resumption(subscription_id: string, params?: any): RequestWrapper;
    static move(subscription_id: string, params?: _subscription.move_params): RequestWrapper;
}
export declare class SubscriptionItem extends Model {
    item_price_id: string;
    item_type: string;
    quantity?: number;
    quantity_in_decimal?: string;
    metered_quantity?: string;
    last_calculated_at?: number;
    unit_price?: number;
    unit_price_in_decimal?: string;
    amount?: number;
    current_term_start?: number;
    current_term_end?: number;
    next_billing_at?: number;
    amount_in_decimal?: string;
    billing_period?: number;
    billing_period_unit?: string;
    free_quantity?: number;
    free_quantity_in_decimal?: string;
    trial_end?: number;
    billing_cycles?: number;
    service_period_days?: number;
    charge_on_event?: string;
    charge_once?: boolean;
    charge_on_option?: string;
    proration_type?: string;
    usage_accumulation_reset_frequency?: string;
}
export declare class ItemTier extends Model {
    item_price_id: string;
    starting_unit: number;
    ending_unit?: number;
    price: number;
    starting_unit_in_decimal?: string;
    ending_unit_in_decimal?: string;
    price_in_decimal?: string;
    pricing_type?: string;
    package_size?: number;
    index: number;
}
export declare class ChargedItem extends Model {
    item_price_id: string;
    last_charged_at: number;
}
export declare class Addon extends Model {
    id: string;
    quantity?: number;
    unit_price?: number;
    amount?: number;
    trial_end?: number;
    remaining_billing_cycles?: number;
    quantity_in_decimal?: string;
    unit_price_in_decimal?: string;
    amount_in_decimal?: string;
    proration_type?: string;
}
export declare class EventBasedAddon extends Model {
    id: string;
    quantity: number;
    unit_price: number;
    service_period_in_days?: number;
    on_event: string;
    charge_once: boolean;
    quantity_in_decimal?: string;
    unit_price_in_decimal?: string;
}
export declare class ChargedEventBasedAddon extends Model {
    id: string;
    last_charged_at: number;
}
export declare class Coupon extends Model {
    coupon_id: string;
    apply_till?: number;
    applied_count: number;
    coupon_code?: string;
}
export declare class ShippingAddress extends Model {
    first_name?: string;
    last_name?: string;
    email?: string;
    company?: string;
    phone?: string;
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state_code?: string;
    state?: string;
    country?: string;
    zip?: string;
    validation_status?: string;
    index: number;
}
export declare class ReferralInfo extends Model {
    referral_code?: string;
    coupon_code?: string;
    referrer_id?: string;
    external_reference_id?: string;
    reward_status?: string;
    referral_system?: string;
    account_id: string;
    campaign_id: string;
    external_campaign_id?: string;
    friend_offer_type?: string;
    referrer_reward_type?: string;
    notify_referral_system?: string;
    destination_url?: string;
    post_purchase_widget_enabled: boolean;
}
export declare class BillingOverride extends Model {
    max_excess_payment_usage?: number;
    max_refundable_credits_usage?: number;
}
export declare class ContractTerm extends Model {
    id: string;
    status: string;
    contract_start: number;
    contract_end: number;
    billing_cycle: number;
    action_at_term_end: string;
    total_contract_value: number;
    total_contract_value_before_tax: number;
    cancellation_cutoff_period?: number;
    created_at: number;
    subscription_id: string;
    remaining_billing_cycles?: number;
}
export declare class Discount extends Model {
    id: string;
    invoice_name?: string;
    type: string;
    percentage?: number;
    amount?: number;
    currency_code?: string;
    duration_type: string;
    period?: number;
    period_unit?: string;
    included_in_mrr: boolean;
    apply_on: string;
    item_price_id?: string;
    created_at: number;
    apply_till?: number;
    applied_count?: number;
    coupon_id: string;
    index: number;
}
export declare namespace _subscription {
    interface create_params {
        id?: string;
        plan_id: string;
        plan_quantity?: number;
        plan_quantity_in_decimal?: string;
        plan_unit_price?: number;
        plan_unit_price_in_decimal?: string;
        setup_fee?: number;
        trial_end?: number;
        billing_cycles?: number;
        mandatory_addons_to_remove?: Array<string>;
        start_date?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        auto_collection?: string;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        offline_payment_method?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        token_id?: string;
        affiliate_token?: string;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        created_from_ip?: string;
        invoice_notes?: string;
        invoice_date?: number;
        meta_data?: any;
        invoice_immediately?: boolean;
        free_period?: number;
        free_period_unit?: string;
        contract_term_billing_cycle_on_renewal?: number;
        trial_end_action?: string;
        client_profile_id?: string;
        payment_initiator?: string;
        customer?: customer_create_params;
        card?: card_create_params;
        bank_account?: bank_account_create_params;
        payment_method?: payment_method_create_params;
        payment_intent?: payment_intent_create_params;
        billing_address?: billing_address_create_params;
        shipping_address?: shipping_address_create_params;
        statement_descriptor?: statement_descriptor_create_params;
        contract_term?: contract_term_create_params;
        entity_identifiers?: Array<entity_identifiers_create_params>;
        tax_providers_fields?: Array<tax_providers_fields_create_params>;
        addons?: Array<addons_create_params>;
        event_based_addons?: Array<event_based_addons_create_params>;
        coupons?: Array<coupons_create_params>;
    }
    interface create_for_customer_params {
        id?: string;
        plan_id: string;
        plan_quantity?: number;
        plan_quantity_in_decimal?: string;
        plan_unit_price?: number;
        plan_unit_price_in_decimal?: string;
        setup_fee?: number;
        trial_end?: number;
        billing_cycles?: number;
        mandatory_addons_to_remove?: Array<string>;
        start_date?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        auto_collection?: string;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        offline_payment_method?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        payment_source_id?: string;
        override_relationship?: boolean;
        invoice_notes?: string;
        invoice_date?: number;
        meta_data?: any;
        invoice_immediately?: boolean;
        replace_primary_payment_source?: boolean;
        free_period?: number;
        free_period_unit?: string;
        contract_term_billing_cycle_on_renewal?: number;
        trial_end_action?: string;
        payment_initiator?: string;
        shipping_address?: shipping_address_create_for_customer_params;
        statement_descriptor?: statement_descriptor_create_for_customer_params;
        payment_intent?: payment_intent_create_for_customer_params;
        contract_term?: contract_term_create_for_customer_params;
        addons?: Array<addons_create_for_customer_params>;
        event_based_addons?: Array<event_based_addons_create_for_customer_params>;
        coupons?: Array<coupons_create_for_customer_params>;
    }
    interface create_with_items_params {
        id?: string;
        business_entity_id?: string;
        trial_end?: number;
        billing_cycles?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
        mandatory_items_to_remove?: Array<string>;
        net_term_days?: number;
        start_date?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        auto_collection?: string;
        terms_to_charge?: number;
        billing_alignment_mode?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        payment_source_id?: string;
        override_relationship?: boolean;
        invoice_notes?: string;
        invoice_date?: number;
        meta_data?: any;
        invoice_immediately?: boolean;
        replace_primary_payment_source?: boolean;
        free_period?: number;
        free_period_unit?: string;
        contract_term_billing_cycle_on_renewal?: number;
        create_pending_invoices?: boolean;
        auto_close_invoices?: boolean;
        first_invoice_pending?: boolean;
        trial_end_action?: string;
        payment_initiator?: string;
        shipping_address?: shipping_address_create_with_items_params;
        statement_descriptor?: statement_descriptor_create_with_items_params;
        payment_intent?: payment_intent_create_with_items_params;
        contract_term?: contract_term_create_with_items_params;
        billing_override?: billing_override_create_with_items_params;
        subscription_items?: Array<subscription_items_create_with_items_params>;
        discounts?: Array<discounts_create_with_items_params>;
        item_tiers?: Array<item_tiers_create_with_items_params>;
        coupons?: Array<coupons_create_with_items_params>;
    }
    interface subscription_list_params {
        limit?: number;
        offset?: string;
        include_deleted?: boolean;
        id?: filter._string;
        customer_id?: filter._string;
        plan_id?: filter._string;
        item_id?: filter._string;
        item_price_id?: filter._string;
        status?: filter._enum;
        cancel_reason?: filter._enum;
        cancel_reason_code?: filter._string;
        remaining_billing_cycles?: filter._number;
        created_at?: filter._timestamp;
        activated_at?: filter._timestamp;
        next_billing_at?: filter._timestamp;
        cancelled_at?: filter._timestamp;
        has_scheduled_changes?: filter._boolean;
        updated_at?: filter._timestamp;
        offline_payment_method?: filter._enum;
        auto_close_invoices?: filter._boolean;
        override_relationship?: filter._boolean;
        business_entity_id?: filter._string;
        channel?: filter._enum;
        "sort_by[asc]"?: string;
        "sort_by[desc]"?: string;
    }
    interface subscription_contract_terms_for_subscription_params {
        limit?: number;
        offset?: string;
        "sort_by[asc]"?: string;
        "sort_by[desc]"?: string;
    }
    interface remove_scheduled_cancellation_params {
        billing_cycles?: number;
    }
    interface remove_coupons_params {
        coupon_ids?: Array<string>;
    }
    interface update_params {
        plan_id?: string;
        plan_quantity?: number;
        plan_unit_price?: number;
        setup_fee?: number;
        replace_addon_list?: boolean;
        mandatory_addons_to_remove?: Array<string>;
        plan_quantity_in_decimal?: string;
        plan_unit_price_in_decimal?: string;
        invoice_date?: number;
        start_date?: number;
        trial_end?: number;
        billing_cycles?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        auto_collection?: string;
        offline_payment_method?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        prorate?: boolean;
        end_of_term?: boolean;
        force_term_reset?: boolean;
        reactivate?: boolean;
        token_id?: string;
        invoice_notes?: string;
        meta_data?: any;
        invoice_immediately?: boolean;
        override_relationship?: boolean;
        changes_scheduled_at?: number;
        change_option?: string;
        contract_term_billing_cycle_on_renewal?: number;
        free_period?: number;
        free_period_unit?: string;
        trial_end_action?: string;
        card?: card_update_params;
        payment_method?: payment_method_update_params;
        payment_intent?: payment_intent_update_params;
        billing_address?: billing_address_update_params;
        shipping_address?: shipping_address_update_params;
        statement_descriptor?: statement_descriptor_update_params;
        customer?: customer_update_params;
        contract_term?: contract_term_update_params;
        addons?: Array<addons_update_params>;
        coupons?: Array<coupons_update_params>;
        event_based_addons?: Array<event_based_addons_update_params>;
    }
    interface update_for_items_params {
        mandatory_items_to_remove?: Array<string>;
        replace_items_list?: boolean;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
        net_term_days?: number;
        invoice_date?: number;
        start_date?: number;
        trial_end?: number;
        billing_cycles?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon?: string;
        terms_to_charge?: number;
        reactivate_from?: number;
        billing_alignment_mode?: string;
        auto_collection?: string;
        offline_payment_method?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        replace_coupon_list?: boolean;
        prorate?: boolean;
        end_of_term?: boolean;
        force_term_reset?: boolean;
        reactivate?: boolean;
        token_id?: string;
        invoice_notes?: string;
        meta_data?: any;
        invoice_immediately?: boolean;
        override_relationship?: boolean;
        changes_scheduled_at?: number;
        change_option?: string;
        contract_term_billing_cycle_on_renewal?: number;
        free_period?: number;
        free_period_unit?: string;
        create_pending_invoices?: boolean;
        auto_close_invoices?: boolean;
        trial_end_action?: string;
        payment_initiator?: string;
        invoice_usages?: boolean;
        card?: card_update_for_items_params;
        payment_method?: payment_method_update_for_items_params;
        payment_intent?: payment_intent_update_for_items_params;
        billing_address?: billing_address_update_for_items_params;
        shipping_address?: shipping_address_update_for_items_params;
        statement_descriptor?: statement_descriptor_update_for_items_params;
        customer?: customer_update_for_items_params;
        contract_term?: contract_term_update_for_items_params;
        billing_override?: billing_override_update_for_items_params;
        subscription_items?: Array<subscription_items_update_for_items_params>;
        discounts?: Array<discounts_update_for_items_params>;
        item_tiers?: Array<item_tiers_update_for_items_params>;
        coupons?: Array<coupons_update_for_items_params>;
    }
    interface change_term_end_params {
        term_ends_at: number;
        prorate?: boolean;
        invoice_immediately?: boolean;
    }
    interface reactivate_params {
        trial_end?: number;
        billing_cycles?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        trial_period_days?: number;
        reactivate_from?: number;
        invoice_immediately?: boolean;
        billing_alignment_mode?: string;
        terms_to_charge?: number;
        invoice_date?: number;
        contract_term_billing_cycle_on_renewal?: number;
        payment_initiator?: string;
        contract_term?: contract_term_reactivate_params;
        statement_descriptor?: statement_descriptor_reactivate_params;
        payment_intent?: payment_intent_reactivate_params;
    }
    interface add_charge_at_term_end_params {
        amount?: number;
        description: string;
        amount_in_decimal?: string;
        avalara_sale_type?: string;
        avalara_transaction_type?: number;
        avalara_service_type?: number;
        date_from?: number;
        date_to?: number;
    }
    interface charge_addon_at_term_end_params {
        addon_id: string;
        addon_quantity?: number;
        addon_unit_price?: number;
        addon_quantity_in_decimal?: string;
        addon_unit_price_in_decimal?: string;
        date_from?: number;
        date_to?: number;
    }
    interface charge_future_renewals_params {
        terms_to_charge?: number;
        invoice_immediately?: boolean;
        schedule_type?: string;
        fixed_interval_schedule?: fixed_interval_schedule_charge_future_renewals_params;
        specific_dates_schedule?: Array<specific_dates_schedule_charge_future_renewals_params>;
    }
    interface edit_advance_invoice_schedule_params {
        terms_to_charge?: number;
        schedule_type?: string;
        fixed_interval_schedule?: fixed_interval_schedule_edit_advance_invoice_schedule_params;
        specific_dates_schedule?: Array<specific_dates_schedule_edit_advance_invoice_schedule_params>;
    }
    interface remove_advance_invoice_schedule_params {
        specific_dates_schedule?: Array<specific_dates_schedule_remove_advance_invoice_schedule_params>;
    }
    interface regenerate_invoice_params {
        date_from?: number;
        date_to?: number;
        prorate?: boolean;
        invoice_immediately?: boolean;
    }
    interface import_subscription_params {
        id?: string;
        client_profile_id?: string;
        plan_id: string;
        plan_quantity?: number;
        plan_quantity_in_decimal?: string;
        plan_unit_price?: number;
        plan_unit_price_in_decimal?: string;
        setup_fee?: number;
        trial_end?: number;
        billing_cycles?: number;
        start_date?: number;
        auto_collection?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        contract_term_billing_cycle_on_renewal?: number;
        status: string;
        current_term_end?: number;
        current_term_start?: number;
        trial_start?: number;
        cancelled_at?: number;
        started_at?: number;
        activated_at?: number;
        pause_date?: number;
        resume_date?: number;
        create_current_term_invoice?: boolean;
        affiliate_token?: string;
        invoice_notes?: string;
        meta_data?: any;
        customer?: customer_import_subscription_params;
        contract_term?: contract_term_import_subscription_params;
        card?: card_import_subscription_params;
        payment_method?: payment_method_import_subscription_params;
        billing_address?: billing_address_import_subscription_params;
        shipping_address?: shipping_address_import_subscription_params;
        transaction?: transaction_import_subscription_params;
        addons?: Array<addons_import_subscription_params>;
        event_based_addons?: Array<event_based_addons_import_subscription_params>;
        charged_event_based_addons?: Array<charged_event_based_addons_import_subscription_params>;
        coupons?: Array<coupons_import_subscription_params>;
    }
    interface import_for_customer_params {
        id?: string;
        plan_id: string;
        plan_quantity?: number;
        plan_quantity_in_decimal?: string;
        plan_unit_price?: number;
        plan_unit_price_in_decimal?: string;
        setup_fee?: number;
        trial_end?: number;
        billing_cycles?: number;
        start_date?: number;
        auto_collection?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        payment_source_id?: string;
        status: string;
        current_term_end?: number;
        current_term_start?: number;
        trial_start?: number;
        cancelled_at?: number;
        started_at?: number;
        activated_at?: number;
        pause_date?: number;
        resume_date?: number;
        contract_term_billing_cycle_on_renewal?: number;
        create_current_term_invoice?: boolean;
        invoice_notes?: string;
        meta_data?: any;
        contract_term?: contract_term_import_for_customer_params;
        transaction?: transaction_import_for_customer_params;
        shipping_address?: shipping_address_import_for_customer_params;
        addons?: Array<addons_import_for_customer_params>;
        event_based_addons?: Array<event_based_addons_import_for_customer_params>;
        charged_event_based_addons?: Array<charged_event_based_addons_import_for_customer_params>;
        coupons?: Array<coupons_import_for_customer_params>;
    }
    interface import_contract_term_params {
        contract_term_billing_cycle_on_renewal?: number;
        contract_term?: contract_term_import_contract_term_params;
    }
    interface import_unbilled_charges_params {
        unbilled_charges?: Array<unbilled_charges_import_unbilled_charges_params>;
        discounts?: Array<discounts_import_unbilled_charges_params>;
        tiers?: Array<tiers_import_unbilled_charges_params>;
    }
    interface import_for_items_params {
        exhausted_coupon_ids?: Array<string>;
        id?: string;
        trial_end?: number;
        billing_cycles?: number;
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        setup_fee?: number;
        net_term_days?: number;
        start_date?: number;
        auto_collection?: string;
        po_number?: string;
        coupon_ids?: Array<string>;
        payment_source_id?: string;
        status: string;
        current_term_end?: number;
        current_term_start?: number;
        trial_start?: number;
        cancelled_at?: number;
        started_at?: number;
        activated_at?: number;
        pause_date?: number;
        resume_date?: number;
        contract_term_billing_cycle_on_renewal?: number;
        create_current_term_invoice?: boolean;
        invoice_notes?: string;
        meta_data?: any;
        cancel_reason_code?: string;
        create_pending_invoices?: boolean;
        auto_close_invoices?: boolean;
        contract_term?: contract_term_import_for_items_params;
        transaction?: transaction_import_for_items_params;
        shipping_address?: shipping_address_import_for_items_params;
        subscription_items?: Array<subscription_items_import_for_items_params>;
        discounts?: Array<discounts_import_for_items_params>;
        charged_items?: Array<charged_items_import_for_items_params>;
        item_tiers?: Array<item_tiers_import_for_items_params>;
        coupons?: Array<coupons_import_for_items_params>;
    }
    interface override_billing_profile_params {
        payment_source_id?: string;
        auto_collection?: string;
    }
    interface pause_params {
        pause_option?: string;
        pause_date?: number;
        unbilled_charges_handling?: string;
        invoice_dunning_handling?: string;
        skip_billing_cycles?: number;
        resume_date?: number;
    }
    interface cancel_params {
        cancel_option?: string;
        end_of_term?: boolean;
        cancel_at?: number;
        credit_option_for_current_term_charges?: string;
        unbilled_charges_option?: string;
        account_receivables_handling?: string;
        refundable_credits_handling?: string;
        contract_term_cancel_option?: string;
        invoice_date?: number;
        cancel_reason_code?: string;
        event_based_addons?: Array<event_based_addons_cancel_params>;
    }
    interface cancel_for_items_params {
        cancel_option?: string;
        end_of_term?: boolean;
        cancel_at?: number;
        credit_option_for_current_term_charges?: string;
        unbilled_charges_option?: string;
        account_receivables_handling?: string;
        refundable_credits_handling?: string;
        contract_term_cancel_option?: string;
        invoice_date?: number;
        cancel_reason_code?: string;
        subscription_items?: Array<subscription_items_cancel_for_items_params>;
    }
    interface resume_params {
        resume_option?: string;
        resume_date?: number;
        charges_handling?: string;
        unpaid_invoices_handling?: string;
        payment_initiator?: string;
        payment_intent?: payment_intent_resume_params;
    }
    interface move_params {
        to_customer_id: string;
        copy_payment_source?: boolean;
    }
    interface customer_create_params {
        id?: string;
    }
    interface customer_create_params {
        email?: string;
    }
    interface customer_create_params {
        first_name?: string;
    }
    interface customer_create_params {
        last_name?: string;
    }
    interface customer_create_params {
        company?: string;
    }
    interface customer_create_params {
        phone?: string;
    }
    interface customer_create_params {
        locale?: string;
    }
    interface customer_create_params {
        taxability?: string;
    }
    interface customer_create_params {
        entity_code?: string;
    }
    interface customer_create_params {
        exempt_number?: string;
    }
    interface customer_create_params {
        net_term_days?: number;
    }
    interface customer_create_params {
        taxjar_exemption_category?: string;
    }
    interface customer_create_params {
        auto_collection?: string;
    }
    interface customer_create_params {
        offline_payment_method?: string;
    }
    interface customer_create_params {
        allow_direct_debit?: boolean;
    }
    interface customer_create_params {
        consolidated_invoicing?: boolean;
    }
    interface customer_create_params {
        vat_number?: string;
    }
    interface customer_create_params {
        vat_number_prefix?: string;
    }
    interface customer_create_params {
        entity_identifier_scheme?: string;
    }
    interface customer_create_params {
        entity_identifier_standard?: string;
    }
    interface customer_create_params {
        is_einvoice_enabled?: boolean;
    }
    interface customer_create_params {
        einvoicing_method?: string;
    }
    interface customer_create_params {
        registered_for_gst?: boolean;
    }
    interface customer_create_params {
        business_customer_without_vat_number?: boolean;
    }
    interface customer_create_params {
        exemption_details?: any;
    }
    interface customer_create_params {
        customer_type?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_create_params {
        gateway_account_id?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_create_params {
        first_name?: string;
    }
    interface card_create_params {
        last_name?: string;
    }
    interface card_create_params {
        number?: string;
    }
    interface card_create_params {
        expiry_month?: number;
    }
    interface card_create_params {
        expiry_year?: number;
    }
    interface card_create_params {
        cvv?: string;
    }
    interface card_create_params {
        preferred_scheme?: string;
    }
    interface card_create_params {
        billing_addr1?: string;
    }
    interface card_create_params {
        billing_addr2?: string;
    }
    interface card_create_params {
        billing_city?: string;
    }
    interface card_create_params {
        billing_state_code?: string;
    }
    interface card_create_params {
        billing_state?: string;
    }
    interface card_create_params {
        billing_zip?: string;
    }
    interface card_create_params {
        billing_country?: string;
    }
    interface card_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        ip_address?: string;
    }
    interface card_create_params {
        additional_information?: any;
    }
    interface bank_account_create_params {
        gateway_account_id?: string;
    }
    interface bank_account_create_params {
        iban?: string;
    }
    interface bank_account_create_params {
        first_name?: string;
    }
    interface bank_account_create_params {
        last_name?: string;
    }
    interface bank_account_create_params {
        company?: string;
    }
    interface bank_account_create_params {
        email?: string;
    }
    interface bank_account_create_params {
        phone?: string;
    }
    interface bank_account_create_params {
        bank_name?: string;
    }
    interface bank_account_create_params {
        account_number?: string;
    }
    interface bank_account_create_params {
        routing_number?: string;
    }
    interface bank_account_create_params {
        bank_code?: string;
    }
    interface bank_account_create_params {
        account_type?: string;
    }
    interface bank_account_create_params {
        account_holder_type?: string;
    }
    interface bank_account_create_params {
        echeck_type?: string;
    }
    interface bank_account_create_params {
        issuing_country?: string;
    }
    interface bank_account_create_params {
        swedish_identity_number?: string;
    }
    interface bank_account_create_params {
        billing_address?: any;
    }
    interface payment_method_create_params {
        type?: string;
    }
    interface payment_method_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_create_params {
        gateway_account_id?: string;
    }
    interface payment_method_create_params {
        reference_id?: string;
    }
    interface payment_method_create_params {
        tmp_token?: string;
    }
    interface payment_method_create_params {
        issuing_country?: string;
    }
    interface payment_method_create_params {
        additional_information?: any;
    }
    interface payment_intent_create_params {
        id?: string;
    }
    interface payment_intent_create_params {
        gateway_account_id?: string;
    }
    interface payment_intent_create_params {
        gw_token?: string;
    }
    interface payment_intent_create_params {
        payment_method_type?: string;
    }
    interface payment_intent_create_params {
        reference_id?: string;
    }
    interface payment_intent_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_create_params {
        additional_information?: any;
    }
    interface billing_address_create_params {
        first_name?: string;
    }
    interface billing_address_create_params {
        last_name?: string;
    }
    interface billing_address_create_params {
        email?: string;
    }
    interface billing_address_create_params {
        company?: string;
    }
    interface billing_address_create_params {
        phone?: string;
    }
    interface billing_address_create_params {
        line1?: string;
    }
    interface billing_address_create_params {
        line2?: string;
    }
    interface billing_address_create_params {
        line3?: string;
    }
    interface billing_address_create_params {
        city?: string;
    }
    interface billing_address_create_params {
        state_code?: string;
    }
    interface billing_address_create_params {
        state?: string;
    }
    interface billing_address_create_params {
        zip?: string;
    }
    interface billing_address_create_params {
        country?: string;
    }
    interface billing_address_create_params {
        validation_status?: string;
    }
    interface shipping_address_create_params {
        first_name?: string;
    }
    interface shipping_address_create_params {
        last_name?: string;
    }
    interface shipping_address_create_params {
        email?: string;
    }
    interface shipping_address_create_params {
        company?: string;
    }
    interface shipping_address_create_params {
        phone?: string;
    }
    interface shipping_address_create_params {
        line1?: string;
    }
    interface shipping_address_create_params {
        line2?: string;
    }
    interface shipping_address_create_params {
        line3?: string;
    }
    interface shipping_address_create_params {
        city?: string;
    }
    interface shipping_address_create_params {
        state_code?: string;
    }
    interface shipping_address_create_params {
        state?: string;
    }
    interface shipping_address_create_params {
        zip?: string;
    }
    interface shipping_address_create_params {
        country?: string;
    }
    interface shipping_address_create_params {
        validation_status?: string;
    }
    interface statement_descriptor_create_params {
        descriptor?: string;
    }
    interface contract_term_create_params {
        action_at_term_end?: string;
    }
    interface contract_term_create_params {
        cancellation_cutoff_period?: number;
    }
    interface entity_identifiers_create_params {
        id?: string;
    }
    interface entity_identifiers_create_params {
        scheme?: string;
    }
    interface entity_identifiers_create_params {
        value?: string;
    }
    interface entity_identifiers_create_params {
        standard?: string;
    }
    interface tax_providers_fields_create_params {
        provider_name?: string;
    }
    interface tax_providers_fields_create_params {
        field_id?: string;
    }
    interface tax_providers_fields_create_params {
        field_value?: string;
    }
    interface addons_create_params {
        id?: string;
    }
    interface addons_create_params {
        quantity?: number;
    }
    interface addons_create_params {
        quantity_in_decimal?: string;
    }
    interface addons_create_params {
        unit_price?: number;
    }
    interface addons_create_params {
        unit_price_in_decimal?: string;
    }
    interface addons_create_params {
        billing_cycles?: number;
    }
    interface event_based_addons_create_params {
        id?: string;
    }
    interface event_based_addons_create_params {
        quantity?: number;
    }
    interface event_based_addons_create_params {
        unit_price?: number;
    }
    interface event_based_addons_create_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_create_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_create_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_create_params {
        on_event?: string;
    }
    interface event_based_addons_create_params {
        charge_once?: boolean;
    }
    interface event_based_addons_create_params {
        charge_on?: string;
    }
    interface addons_create_params {
        trial_end?: number;
    }
    interface coupons_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_create_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface shipping_address_create_for_customer_params {
        first_name?: string;
    }
    interface shipping_address_create_for_customer_params {
        last_name?: string;
    }
    interface shipping_address_create_for_customer_params {
        email?: string;
    }
    interface shipping_address_create_for_customer_params {
        company?: string;
    }
    interface shipping_address_create_for_customer_params {
        phone?: string;
    }
    interface shipping_address_create_for_customer_params {
        line1?: string;
    }
    interface shipping_address_create_for_customer_params {
        line2?: string;
    }
    interface shipping_address_create_for_customer_params {
        line3?: string;
    }
    interface shipping_address_create_for_customer_params {
        city?: string;
    }
    interface shipping_address_create_for_customer_params {
        state_code?: string;
    }
    interface shipping_address_create_for_customer_params {
        state?: string;
    }
    interface shipping_address_create_for_customer_params {
        zip?: string;
    }
    interface shipping_address_create_for_customer_params {
        country?: string;
    }
    interface shipping_address_create_for_customer_params {
        validation_status?: string;
    }
    interface statement_descriptor_create_for_customer_params {
        descriptor?: string;
    }
    interface payment_intent_create_for_customer_params {
        id?: string;
    }
    interface payment_intent_create_for_customer_params {
        gateway_account_id?: string;
    }
    interface payment_intent_create_for_customer_params {
        gw_token?: string;
    }
    interface payment_intent_create_for_customer_params {
        payment_method_type?: string;
    }
    interface payment_intent_create_for_customer_params {
        reference_id?: string;
    }
    interface payment_intent_create_for_customer_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_create_for_customer_params {
        additional_information?: any;
    }
    interface contract_term_create_for_customer_params {
        action_at_term_end?: string;
    }
    interface contract_term_create_for_customer_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_create_for_customer_params {
        id?: string;
    }
    interface addons_create_for_customer_params {
        quantity?: number;
    }
    interface addons_create_for_customer_params {
        quantity_in_decimal?: string;
    }
    interface addons_create_for_customer_params {
        unit_price?: number;
    }
    interface addons_create_for_customer_params {
        unit_price_in_decimal?: string;
    }
    interface addons_create_for_customer_params {
        billing_cycles?: number;
    }
    interface event_based_addons_create_for_customer_params {
        id?: string;
    }
    interface event_based_addons_create_for_customer_params {
        quantity?: number;
    }
    interface event_based_addons_create_for_customer_params {
        unit_price?: number;
    }
    interface event_based_addons_create_for_customer_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_create_for_customer_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_create_for_customer_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_create_for_customer_params {
        on_event?: string;
    }
    interface event_based_addons_create_for_customer_params {
        charge_once?: boolean;
    }
    interface event_based_addons_create_for_customer_params {
        charge_on?: string;
    }
    interface addons_create_for_customer_params {
        trial_end?: number;
    }
    interface coupons_create_for_customer_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_create_for_customer_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface shipping_address_create_with_items_params {
        first_name?: string;
    }
    interface shipping_address_create_with_items_params {
        last_name?: string;
    }
    interface shipping_address_create_with_items_params {
        email?: string;
    }
    interface shipping_address_create_with_items_params {
        company?: string;
    }
    interface shipping_address_create_with_items_params {
        phone?: string;
    }
    interface shipping_address_create_with_items_params {
        line1?: string;
    }
    interface shipping_address_create_with_items_params {
        line2?: string;
    }
    interface shipping_address_create_with_items_params {
        line3?: string;
    }
    interface shipping_address_create_with_items_params {
        city?: string;
    }
    interface shipping_address_create_with_items_params {
        state_code?: string;
    }
    interface shipping_address_create_with_items_params {
        state?: string;
    }
    interface shipping_address_create_with_items_params {
        zip?: string;
    }
    interface shipping_address_create_with_items_params {
        country?: string;
    }
    interface shipping_address_create_with_items_params {
        validation_status?: string;
    }
    interface statement_descriptor_create_with_items_params {
        descriptor?: string;
    }
    interface payment_intent_create_with_items_params {
        id?: string;
    }
    interface payment_intent_create_with_items_params {
        gateway_account_id?: string;
    }
    interface payment_intent_create_with_items_params {
        gw_token?: string;
    }
    interface payment_intent_create_with_items_params {
        payment_method_type?: string;
    }
    interface payment_intent_create_with_items_params {
        reference_id?: string;
    }
    interface payment_intent_create_with_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_create_with_items_params {
        additional_information?: any;
    }
    interface contract_term_create_with_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_create_with_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        contract_start?: number;
    }
    interface contract_term_create_with_items_params {
        cancellation_cutoff_period?: number;
    }
    interface billing_override_create_with_items_params {
        max_excess_payment_usage?: number;
    }
    interface billing_override_create_with_items_params {
        max_refundable_credits_usage?: number;
    }
    interface subscription_items_create_with_items_params {
        item_price_id: string;
    }
    interface subscription_items_create_with_items_params {
        quantity?: number;
    }
    interface subscription_items_create_with_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_create_with_items_params {
        unit_price?: number;
    }
    interface subscription_items_create_with_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_create_with_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_create_with_items_params {
        trial_end?: number;
    }
    interface subscription_items_create_with_items_params {
        service_period_days?: number;
    }
    interface subscription_items_create_with_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_create_with_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_create_with_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_create_with_items_params {
        apply_on?: string;
    }
    interface discounts_create_with_items_params {
        duration_type: string;
    }
    interface discounts_create_with_items_params {
        percentage?: number;
    }
    interface discounts_create_with_items_params {
        amount?: number;
    }
    interface discounts_create_with_items_params {
        period?: number;
    }
    interface discounts_create_with_items_params {
        period_unit?: string;
    }
    interface discounts_create_with_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_create_with_items_params {
        item_price_id?: string;
    }
    interface subscription_items_create_with_items_params {
        charge_on_option?: string;
    }
    interface item_tiers_create_with_items_params {
        item_price_id?: string;
    }
    interface item_tiers_create_with_items_params {
        starting_unit?: number;
    }
    interface item_tiers_create_with_items_params {
        ending_unit?: number;
    }
    interface item_tiers_create_with_items_params {
        price?: number;
    }
    interface item_tiers_create_with_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_create_with_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_create_with_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_create_with_items_params {
        pricing_type?: string;
    }
    interface item_tiers_create_with_items_params {
        package_size?: number;
    }
    interface coupons_create_with_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_create_with_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface subscription_items_create_with_items_params {
        usage_accumulation_reset_frequency?: string;
    }
    interface card_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_update_params {
        gateway_account_id?: string;
    }
    interface card_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_update_params {
        first_name?: string;
    }
    interface card_update_params {
        last_name?: string;
    }
    interface card_update_params {
        number?: string;
    }
    interface card_update_params {
        expiry_month?: number;
    }
    interface card_update_params {
        expiry_year?: number;
    }
    interface card_update_params {
        cvv?: string;
    }
    interface card_update_params {
        preferred_scheme?: string;
    }
    interface card_update_params {
        billing_addr1?: string;
    }
    interface card_update_params {
        billing_addr2?: string;
    }
    interface card_update_params {
        billing_city?: string;
    }
    interface card_update_params {
        billing_state_code?: string;
    }
    interface card_update_params {
        billing_state?: string;
    }
    interface card_update_params {
        billing_zip?: string;
    }
    interface card_update_params {
        billing_country?: string;
    }
    interface card_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        ip_address?: string;
    }
    interface card_update_params {
        additional_information?: any;
    }
    interface payment_method_update_params {
        type?: string;
    }
    interface payment_method_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_update_params {
        gateway_account_id?: string;
    }
    interface payment_method_update_params {
        reference_id?: string;
    }
    interface payment_method_update_params {
        tmp_token?: string;
    }
    interface payment_method_update_params {
        issuing_country?: string;
    }
    interface payment_method_update_params {
        additional_information?: any;
    }
    interface payment_intent_update_params {
        id?: string;
    }
    interface payment_intent_update_params {
        gateway_account_id?: string;
    }
    interface payment_intent_update_params {
        gw_token?: string;
    }
    interface payment_intent_update_params {
        payment_method_type?: string;
    }
    interface payment_intent_update_params {
        reference_id?: string;
    }
    interface payment_intent_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_update_params {
        additional_information?: any;
    }
    interface billing_address_update_params {
        first_name?: string;
    }
    interface billing_address_update_params {
        last_name?: string;
    }
    interface billing_address_update_params {
        email?: string;
    }
    interface billing_address_update_params {
        company?: string;
    }
    interface billing_address_update_params {
        phone?: string;
    }
    interface billing_address_update_params {
        line1?: string;
    }
    interface billing_address_update_params {
        line2?: string;
    }
    interface billing_address_update_params {
        line3?: string;
    }
    interface billing_address_update_params {
        city?: string;
    }
    interface billing_address_update_params {
        state_code?: string;
    }
    interface billing_address_update_params {
        state?: string;
    }
    interface billing_address_update_params {
        zip?: string;
    }
    interface billing_address_update_params {
        country?: string;
    }
    interface billing_address_update_params {
        validation_status?: string;
    }
    interface shipping_address_update_params {
        first_name?: string;
    }
    interface shipping_address_update_params {
        last_name?: string;
    }
    interface shipping_address_update_params {
        email?: string;
    }
    interface shipping_address_update_params {
        company?: string;
    }
    interface shipping_address_update_params {
        phone?: string;
    }
    interface shipping_address_update_params {
        line1?: string;
    }
    interface shipping_address_update_params {
        line2?: string;
    }
    interface shipping_address_update_params {
        line3?: string;
    }
    interface shipping_address_update_params {
        city?: string;
    }
    interface shipping_address_update_params {
        state_code?: string;
    }
    interface shipping_address_update_params {
        state?: string;
    }
    interface shipping_address_update_params {
        zip?: string;
    }
    interface shipping_address_update_params {
        country?: string;
    }
    interface shipping_address_update_params {
        validation_status?: string;
    }
    interface statement_descriptor_update_params {
        descriptor?: string;
    }
    interface customer_update_params {
        vat_number?: string;
    }
    interface customer_update_params {
        vat_number_prefix?: string;
    }
    interface customer_update_params {
        entity_identifier_scheme?: string;
    }
    interface customer_update_params {
        is_einvoice_enabled?: boolean;
    }
    interface customer_update_params {
        einvoicing_method?: string;
    }
    interface customer_update_params {
        entity_identifier_standard?: string;
    }
    interface customer_update_params {
        business_customer_without_vat_number?: boolean;
    }
    interface customer_update_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_update_params {
        action_at_term_end?: string;
    }
    interface contract_term_update_params {
        cancellation_cutoff_period?: number;
    }
    interface addons_update_params {
        id?: string;
    }
    interface addons_update_params {
        quantity?: number;
    }
    interface addons_update_params {
        unit_price?: number;
    }
    interface addons_update_params {
        billing_cycles?: number;
    }
    interface addons_update_params {
        quantity_in_decimal?: string;
    }
    interface addons_update_params {
        unit_price_in_decimal?: string;
    }
    interface addons_update_params {
        trial_end?: number;
    }
    interface addons_update_params {
        proration_type?: string;
    }
    interface coupons_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_update_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface event_based_addons_update_params {
        id?: string;
    }
    interface event_based_addons_update_params {
        quantity?: number;
    }
    interface event_based_addons_update_params {
        unit_price?: number;
    }
    interface event_based_addons_update_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_update_params {
        charge_on?: string;
    }
    interface event_based_addons_update_params {
        on_event?: string;
    }
    interface event_based_addons_update_params {
        charge_once?: boolean;
    }
    interface event_based_addons_update_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_update_params {
        unit_price_in_decimal?: string;
    }
    interface card_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_update_for_items_params {
        gateway_account_id?: string;
    }
    interface card_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_update_for_items_params {
        first_name?: string;
    }
    interface card_update_for_items_params {
        last_name?: string;
    }
    interface card_update_for_items_params {
        number?: string;
    }
    interface card_update_for_items_params {
        expiry_month?: number;
    }
    interface card_update_for_items_params {
        expiry_year?: number;
    }
    interface card_update_for_items_params {
        cvv?: string;
    }
    interface card_update_for_items_params {
        preferred_scheme?: string;
    }
    interface card_update_for_items_params {
        billing_addr1?: string;
    }
    interface card_update_for_items_params {
        billing_addr2?: string;
    }
    interface card_update_for_items_params {
        billing_city?: string;
    }
    interface card_update_for_items_params {
        billing_state_code?: string;
    }
    interface card_update_for_items_params {
        billing_state?: string;
    }
    interface card_update_for_items_params {
        billing_zip?: string;
    }
    interface card_update_for_items_params {
        billing_country?: string;
    }
    interface card_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        ip_address?: string;
    }
    interface card_update_for_items_params {
        additional_information?: any;
    }
    interface payment_method_update_for_items_params {
        type?: string;
    }
    interface payment_method_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_update_for_items_params {
        gateway_account_id?: string;
    }
    interface payment_method_update_for_items_params {
        reference_id?: string;
    }
    interface payment_method_update_for_items_params {
        tmp_token?: string;
    }
    interface payment_method_update_for_items_params {
        issuing_country?: string;
    }
    interface payment_method_update_for_items_params {
        additional_information?: any;
    }
    interface payment_intent_update_for_items_params {
        id?: string;
    }
    interface payment_intent_update_for_items_params {
        gateway_account_id?: string;
    }
    interface payment_intent_update_for_items_params {
        gw_token?: string;
    }
    interface payment_intent_update_for_items_params {
        payment_method_type?: string;
    }
    interface payment_intent_update_for_items_params {
        reference_id?: string;
    }
    interface payment_intent_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_update_for_items_params {
        additional_information?: any;
    }
    interface billing_address_update_for_items_params {
        first_name?: string;
    }
    interface billing_address_update_for_items_params {
        last_name?: string;
    }
    interface billing_address_update_for_items_params {
        email?: string;
    }
    interface billing_address_update_for_items_params {
        company?: string;
    }
    interface billing_address_update_for_items_params {
        phone?: string;
    }
    interface billing_address_update_for_items_params {
        line1?: string;
    }
    interface billing_address_update_for_items_params {
        line2?: string;
    }
    interface billing_address_update_for_items_params {
        line3?: string;
    }
    interface billing_address_update_for_items_params {
        city?: string;
    }
    interface billing_address_update_for_items_params {
        state_code?: string;
    }
    interface billing_address_update_for_items_params {
        state?: string;
    }
    interface billing_address_update_for_items_params {
        zip?: string;
    }
    interface billing_address_update_for_items_params {
        country?: string;
    }
    interface billing_address_update_for_items_params {
        validation_status?: string;
    }
    interface shipping_address_update_for_items_params {
        first_name?: string;
    }
    interface shipping_address_update_for_items_params {
        last_name?: string;
    }
    interface shipping_address_update_for_items_params {
        email?: string;
    }
    interface shipping_address_update_for_items_params {
        company?: string;
    }
    interface shipping_address_update_for_items_params {
        phone?: string;
    }
    interface shipping_address_update_for_items_params {
        line1?: string;
    }
    interface shipping_address_update_for_items_params {
        line2?: string;
    }
    interface shipping_address_update_for_items_params {
        line3?: string;
    }
    interface shipping_address_update_for_items_params {
        city?: string;
    }
    interface shipping_address_update_for_items_params {
        state_code?: string;
    }
    interface shipping_address_update_for_items_params {
        state?: string;
    }
    interface shipping_address_update_for_items_params {
        zip?: string;
    }
    interface shipping_address_update_for_items_params {
        country?: string;
    }
    interface shipping_address_update_for_items_params {
        validation_status?: string;
    }
    interface statement_descriptor_update_for_items_params {
        descriptor?: string;
    }
    interface customer_update_for_items_params {
        vat_number?: string;
    }
    interface customer_update_for_items_params {
        vat_number_prefix?: string;
    }
    interface customer_update_for_items_params {
        entity_identifier_scheme?: string;
    }
    interface customer_update_for_items_params {
        is_einvoice_enabled?: boolean;
    }
    interface customer_update_for_items_params {
        einvoicing_method?: string;
    }
    interface customer_update_for_items_params {
        entity_identifier_standard?: string;
    }
    interface customer_update_for_items_params {
        business_customer_without_vat_number?: boolean;
    }
    interface customer_update_for_items_params {
        registered_for_gst?: boolean;
    }
    interface contract_term_update_for_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_update_for_items_params {
        cancellation_cutoff_period?: number;
    }
    interface contract_term_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        contract_start?: number;
    }
    interface billing_override_update_for_items_params {
        max_excess_payment_usage?: number;
    }
    interface billing_override_update_for_items_params {
        max_refundable_credits_usage?: number;
    }
    interface subscription_items_update_for_items_params {
        item_price_id: string;
    }
    interface subscription_items_update_for_items_params {
        quantity?: number;
    }
    interface subscription_items_update_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_update_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_update_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_update_for_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_update_for_items_params {
        trial_end?: number;
    }
    interface subscription_items_update_for_items_params {
        service_period_days?: number;
    }
    interface subscription_items_update_for_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_update_for_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_update_for_items_params {
        charge_on_option?: string;
    }
    interface subscription_items_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_update_for_items_params {
        apply_on?: string;
    }
    interface discounts_update_for_items_params {
        duration_type: string;
    }
    interface discounts_update_for_items_params {
        percentage?: number;
    }
    interface discounts_update_for_items_params {
        amount?: number;
    }
    interface discounts_update_for_items_params {
        period?: number;
    }
    interface discounts_update_for_items_params {
        period_unit?: string;
    }
    interface discounts_update_for_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_update_for_items_params {
        item_price_id?: string;
    }
    interface discounts_update_for_items_params {
        operation_type: string;
    }
    interface discounts_update_for_items_params {
        id?: string;
    }
    interface item_tiers_update_for_items_params {
        item_price_id?: string;
    }
    interface item_tiers_update_for_items_params {
        starting_unit?: number;
    }
    interface item_tiers_update_for_items_params {
        ending_unit?: number;
    }
    interface item_tiers_update_for_items_params {
        price?: number;
    }
    interface item_tiers_update_for_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_update_for_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_update_for_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_update_for_items_params {
        pricing_type?: string;
    }
    interface item_tiers_update_for_items_params {
        package_size?: number;
    }
    interface subscription_items_update_for_items_params {
        proration_type?: string;
    }
    interface coupons_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_update_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface subscription_items_update_for_items_params {
        usage_accumulation_reset_frequency?: string;
    }
    interface contract_term_reactivate_params {
        action_at_term_end?: string;
    }
    interface contract_term_reactivate_params {
        cancellation_cutoff_period?: number;
    }
    interface statement_descriptor_reactivate_params {
        descriptor?: string;
    }
    interface payment_intent_reactivate_params {
        id?: string;
    }
    interface payment_intent_reactivate_params {
        gateway_account_id?: string;
    }
    interface payment_intent_reactivate_params {
        gw_token?: string;
    }
    interface payment_intent_reactivate_params {
        payment_method_type?: string;
    }
    interface payment_intent_reactivate_params {
        reference_id?: string;
    }
    interface payment_intent_reactivate_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_reactivate_params {
        additional_information?: any;
    }
    interface fixed_interval_schedule_charge_future_renewals_params {
        number_of_occurrences?: number;
    }
    interface fixed_interval_schedule_charge_future_renewals_params {
        days_before_renewal?: number;
    }
    interface fixed_interval_schedule_charge_future_renewals_params {
        end_schedule_on?: string;
    }
    interface fixed_interval_schedule_charge_future_renewals_params {
        end_date?: number;
    }
    interface specific_dates_schedule_charge_future_renewals_params {
        terms_to_charge?: number;
    }
    interface specific_dates_schedule_charge_future_renewals_params {
        date?: number;
    }
    interface fixed_interval_schedule_edit_advance_invoice_schedule_params {
        number_of_occurrences?: number;
    }
    interface fixed_interval_schedule_edit_advance_invoice_schedule_params {
        days_before_renewal?: number;
    }
    interface fixed_interval_schedule_edit_advance_invoice_schedule_params {
        end_schedule_on?: string;
    }
    interface fixed_interval_schedule_edit_advance_invoice_schedule_params {
        end_date?: number;
    }
    interface specific_dates_schedule_edit_advance_invoice_schedule_params {
        id?: string;
    }
    interface specific_dates_schedule_edit_advance_invoice_schedule_params {
        terms_to_charge?: number;
    }
    interface specific_dates_schedule_edit_advance_invoice_schedule_params {
        date?: number;
    }
    interface specific_dates_schedule_remove_advance_invoice_schedule_params {
        id?: string;
    }
    interface customer_import_subscription_params {
        id?: string;
    }
    interface customer_import_subscription_params {
        email?: string;
    }
    interface customer_import_subscription_params {
        first_name?: string;
    }
    interface customer_import_subscription_params {
        last_name?: string;
    }
    interface customer_import_subscription_params {
        company?: string;
    }
    interface customer_import_subscription_params {
        phone?: string;
    }
    interface customer_import_subscription_params {
        locale?: string;
    }
    interface customer_import_subscription_params {
        taxability?: string;
    }
    interface customer_import_subscription_params {
        entity_code?: string;
    }
    interface customer_import_subscription_params {
        exempt_number?: string;
    }
    interface customer_import_subscription_params {
        net_term_days?: number;
    }
    interface customer_import_subscription_params {
        taxjar_exemption_category?: string;
    }
    interface customer_import_subscription_params {
        customer_type?: string;
    }
    interface customer_import_subscription_params {
        auto_collection?: string;
    }
    interface customer_import_subscription_params {
        allow_direct_debit?: boolean;
    }
    interface customer_import_subscription_params {
        vat_number?: string;
    }
    interface customer_import_subscription_params {
        vat_number_prefix?: string;
    }
    interface contract_term_import_subscription_params {
        id?: string;
    }
    interface contract_term_import_subscription_params {
        created_at?: number;
    }
    interface contract_term_import_subscription_params {
        contract_start?: number;
    }
    interface contract_term_import_subscription_params {
        billing_cycle?: number;
    }
    interface contract_term_import_subscription_params {
        total_amount_raised?: number;
    }
    interface contract_term_import_subscription_params {
        total_amount_raised_before_tax?: number;
    }
    interface contract_term_import_subscription_params {
        action_at_term_end?: string;
    }
    interface contract_term_import_subscription_params {
        cancellation_cutoff_period?: number;
    }
    interface card_import_subscription_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface card_import_subscription_params {
        gateway_account_id?: string;
    }
    interface card_import_subscription_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        tmp_token?: string;
    }
    interface card_import_subscription_params {
        first_name?: string;
    }
    interface card_import_subscription_params {
        last_name?: string;
    }
    interface card_import_subscription_params {
        number?: string;
    }
    interface card_import_subscription_params {
        expiry_month?: number;
    }
    interface card_import_subscription_params {
        expiry_year?: number;
    }
    interface card_import_subscription_params {
        cvv?: string;
    }
    interface card_import_subscription_params {
        preferred_scheme?: string;
    }
    interface card_import_subscription_params {
        billing_addr1?: string;
    }
    interface card_import_subscription_params {
        billing_addr2?: string;
    }
    interface card_import_subscription_params {
        billing_city?: string;
    }
    interface card_import_subscription_params {
        billing_state_code?: string;
    }
    interface card_import_subscription_params {
        billing_state?: string;
    }
    interface card_import_subscription_params {
        billing_zip?: string;
    }
    interface card_import_subscription_params {
        billing_country?: string;
    }
    interface card_import_subscription_params {
        additional_information?: any;
    }
    interface payment_method_import_subscription_params {
        type?: string;
    }
    interface payment_method_import_subscription_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gateway?: string;
    }
    interface payment_method_import_subscription_params {
        gateway_account_id?: string;
    }
    interface payment_method_import_subscription_params {
        reference_id?: string;
    }
    interface payment_method_import_subscription_params {
        issuing_country?: string;
    }
    interface payment_method_import_subscription_params {
        additional_information?: any;
    }
    interface billing_address_import_subscription_params {
        first_name?: string;
    }
    interface billing_address_import_subscription_params {
        last_name?: string;
    }
    interface billing_address_import_subscription_params {
        email?: string;
    }
    interface billing_address_import_subscription_params {
        company?: string;
    }
    interface billing_address_import_subscription_params {
        phone?: string;
    }
    interface billing_address_import_subscription_params {
        line1?: string;
    }
    interface billing_address_import_subscription_params {
        line2?: string;
    }
    interface billing_address_import_subscription_params {
        line3?: string;
    }
    interface billing_address_import_subscription_params {
        city?: string;
    }
    interface billing_address_import_subscription_params {
        state_code?: string;
    }
    interface billing_address_import_subscription_params {
        state?: string;
    }
    interface billing_address_import_subscription_params {
        zip?: string;
    }
    interface billing_address_import_subscription_params {
        country?: string;
    }
    interface billing_address_import_subscription_params {
        validation_status?: string;
    }
    interface shipping_address_import_subscription_params {
        first_name?: string;
    }
    interface shipping_address_import_subscription_params {
        last_name?: string;
    }
    interface shipping_address_import_subscription_params {
        email?: string;
    }
    interface shipping_address_import_subscription_params {
        company?: string;
    }
    interface shipping_address_import_subscription_params {
        phone?: string;
    }
    interface shipping_address_import_subscription_params {
        line1?: string;
    }
    interface shipping_address_import_subscription_params {
        line2?: string;
    }
    interface shipping_address_import_subscription_params {
        line3?: string;
    }
    interface shipping_address_import_subscription_params {
        city?: string;
    }
    interface shipping_address_import_subscription_params {
        state_code?: string;
    }
    interface shipping_address_import_subscription_params {
        state?: string;
    }
    interface shipping_address_import_subscription_params {
        zip?: string;
    }
    interface shipping_address_import_subscription_params {
        country?: string;
    }
    interface shipping_address_import_subscription_params {
        validation_status?: string;
    }
    interface transaction_import_subscription_params {
        amount?: number;
    }
    interface transaction_import_subscription_params {
        payment_method?: string;
    }
    interface transaction_import_subscription_params {
        reference_number?: string;
    }
    interface transaction_import_subscription_params {
        date?: number;
    }
    interface addons_import_subscription_params {
        id?: string;
    }
    interface addons_import_subscription_params {
        quantity?: number;
    }
    interface addons_import_subscription_params {
        quantity_in_decimal?: string;
    }
    interface addons_import_subscription_params {
        unit_price?: number;
    }
    interface addons_import_subscription_params {
        unit_price_in_decimal?: string;
    }
    interface addons_import_subscription_params {
        billing_cycles?: number;
    }
    interface event_based_addons_import_subscription_params {
        id?: string;
    }
    interface event_based_addons_import_subscription_params {
        quantity?: number;
    }
    interface event_based_addons_import_subscription_params {
        unit_price?: number;
    }
    interface event_based_addons_import_subscription_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_import_subscription_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_import_subscription_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_import_subscription_params {
        on_event?: string;
    }
    interface event_based_addons_import_subscription_params {
        charge_once?: boolean;
    }
    interface charged_event_based_addons_import_subscription_params {
        id?: string;
    }
    interface charged_event_based_addons_import_subscription_params {
        last_charged_at?: number;
    }
    interface coupons_import_subscription_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_import_subscription_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface contract_term_import_for_customer_params {
        id?: string;
    }
    interface contract_term_import_for_customer_params {
        created_at?: number;
    }
    interface contract_term_import_for_customer_params {
        contract_start?: number;
    }
    interface contract_term_import_for_customer_params {
        billing_cycle?: number;
    }
    interface contract_term_import_for_customer_params {
        total_amount_raised?: number;
    }
    interface contract_term_import_for_customer_params {
        total_amount_raised_before_tax?: number;
    }
    interface contract_term_import_for_customer_params {
        action_at_term_end?: string;
    }
    interface contract_term_import_for_customer_params {
        cancellation_cutoff_period?: number;
    }
    interface transaction_import_for_customer_params {
        amount?: number;
    }
    interface transaction_import_for_customer_params {
        payment_method?: string;
    }
    interface transaction_import_for_customer_params {
        reference_number?: string;
    }
    interface transaction_import_for_customer_params {
        date?: number;
    }
    interface shipping_address_import_for_customer_params {
        first_name?: string;
    }
    interface shipping_address_import_for_customer_params {
        last_name?: string;
    }
    interface shipping_address_import_for_customer_params {
        email?: string;
    }
    interface shipping_address_import_for_customer_params {
        company?: string;
    }
    interface shipping_address_import_for_customer_params {
        phone?: string;
    }
    interface shipping_address_import_for_customer_params {
        line1?: string;
    }
    interface shipping_address_import_for_customer_params {
        line2?: string;
    }
    interface shipping_address_import_for_customer_params {
        line3?: string;
    }
    interface shipping_address_import_for_customer_params {
        city?: string;
    }
    interface shipping_address_import_for_customer_params {
        state_code?: string;
    }
    interface shipping_address_import_for_customer_params {
        state?: string;
    }
    interface shipping_address_import_for_customer_params {
        zip?: string;
    }
    interface shipping_address_import_for_customer_params {
        country?: string;
    }
    interface shipping_address_import_for_customer_params {
        validation_status?: string;
    }
    interface addons_import_for_customer_params {
        id?: string;
    }
    interface addons_import_for_customer_params {
        quantity?: number;
    }
    interface addons_import_for_customer_params {
        quantity_in_decimal?: string;
    }
    interface addons_import_for_customer_params {
        unit_price?: number;
    }
    interface addons_import_for_customer_params {
        unit_price_in_decimal?: string;
    }
    interface addons_import_for_customer_params {
        billing_cycles?: number;
    }
    interface event_based_addons_import_for_customer_params {
        id?: string;
    }
    interface event_based_addons_import_for_customer_params {
        quantity?: number;
    }
    interface event_based_addons_import_for_customer_params {
        unit_price?: number;
    }
    interface event_based_addons_import_for_customer_params {
        quantity_in_decimal?: string;
    }
    interface event_based_addons_import_for_customer_params {
        unit_price_in_decimal?: string;
    }
    interface event_based_addons_import_for_customer_params {
        service_period_in_days?: number;
    }
    interface event_based_addons_import_for_customer_params {
        on_event?: string;
    }
    interface event_based_addons_import_for_customer_params {
        charge_once?: boolean;
    }
    interface charged_event_based_addons_import_for_customer_params {
        id?: string;
    }
    interface charged_event_based_addons_import_for_customer_params {
        last_charged_at?: number;
    }
    interface coupons_import_for_customer_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_import_for_customer_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface contract_term_import_contract_term_params {
        id?: string;
    }
    interface contract_term_import_contract_term_params {
        created_at?: number;
    }
    interface contract_term_import_contract_term_params {
        contract_start?: number;
    }
    interface contract_term_import_contract_term_params {
        contract_end?: number;
    }
    interface contract_term_import_contract_term_params {
        status?: string;
    }
    interface contract_term_import_contract_term_params {
        total_amount_raised?: number;
    }
    interface contract_term_import_contract_term_params {
        total_amount_raised_before_tax?: number;
    }
    interface contract_term_import_contract_term_params {
        total_contract_value?: number;
    }
    interface contract_term_import_contract_term_params {
        total_contract_value_before_tax?: number;
    }
    interface contract_term_import_contract_term_params {
        billing_cycle?: number;
    }
    interface contract_term_import_contract_term_params {
        action_at_term_end?: string;
    }
    interface contract_term_import_contract_term_params {
        cancellation_cutoff_period?: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        id?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        date_from: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        date_to: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        entity_type: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        entity_id?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        description?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        unit_amount?: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        quantity?: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        amount?: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        unit_amount_in_decimal?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        quantity_in_decimal?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        amount_in_decimal?: string;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        discount_amount?: number;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        use_for_proration?: boolean;
    }
    interface unbilled_charges_import_unbilled_charges_params {
        is_advance_charge?: boolean;
    }
    interface discounts_import_unbilled_charges_params {
        unbilled_charge_id?: string;
    }
    interface discounts_import_unbilled_charges_params {
        entity_type?: string;
    }
    interface discounts_import_unbilled_charges_params {
        entity_id?: string;
    }
    interface discounts_import_unbilled_charges_params {
        description?: string;
    }
    interface discounts_import_unbilled_charges_params {
        amount: number;
    }
    interface tiers_import_unbilled_charges_params {
        unbilled_charge_id: string;
    }
    interface tiers_import_unbilled_charges_params {
        starting_unit?: number;
    }
    interface tiers_import_unbilled_charges_params {
        ending_unit?: number;
    }
    interface tiers_import_unbilled_charges_params {
        quantity_used?: number;
    }
    interface tiers_import_unbilled_charges_params {
        unit_amount?: number;
    }
    interface tiers_import_unbilled_charges_params {
        starting_unit_in_decimal?: string;
    }
    interface tiers_import_unbilled_charges_params {
        ending_unit_in_decimal?: string;
    }
    interface tiers_import_unbilled_charges_params {
        quantity_used_in_decimal?: string;
    }
    interface tiers_import_unbilled_charges_params {
        unit_amount_in_decimal?: string;
    }
    interface contract_term_import_for_items_params {
        id?: string;
    }
    interface contract_term_import_for_items_params {
        created_at?: number;
    }
    interface contract_term_import_for_items_params {
        contract_start?: number;
    }
    interface contract_term_import_for_items_params {
        billing_cycle?: number;
    }
    interface contract_term_import_for_items_params {
        total_amount_raised?: number;
    }
    interface contract_term_import_for_items_params {
        total_amount_raised_before_tax?: number;
    }
    interface contract_term_import_for_items_params {
        action_at_term_end?: string;
    }
    interface contract_term_import_for_items_params {
        cancellation_cutoff_period?: number;
    }
    interface transaction_import_for_items_params {
        amount?: number;
    }
    interface transaction_import_for_items_params {
        payment_method?: string;
    }
    interface transaction_import_for_items_params {
        reference_number?: string;
    }
    interface transaction_import_for_items_params {
        date?: number;
    }
    interface shipping_address_import_for_items_params {
        first_name?: string;
    }
    interface shipping_address_import_for_items_params {
        last_name?: string;
    }
    interface shipping_address_import_for_items_params {
        email?: string;
    }
    interface shipping_address_import_for_items_params {
        company?: string;
    }
    interface shipping_address_import_for_items_params {
        phone?: string;
    }
    interface shipping_address_import_for_items_params {
        line1?: string;
    }
    interface shipping_address_import_for_items_params {
        line2?: string;
    }
    interface shipping_address_import_for_items_params {
        line3?: string;
    }
    interface shipping_address_import_for_items_params {
        city?: string;
    }
    interface shipping_address_import_for_items_params {
        state_code?: string;
    }
    interface shipping_address_import_for_items_params {
        state?: string;
    }
    interface shipping_address_import_for_items_params {
        zip?: string;
    }
    interface shipping_address_import_for_items_params {
        country?: string;
    }
    interface shipping_address_import_for_items_params {
        validation_status?: string;
    }
    interface subscription_items_import_for_items_params {
        item_price_id: string;
    }
    interface subscription_items_import_for_items_params {
        quantity?: number;
    }
    interface subscription_items_import_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_import_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_import_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_import_for_items_params {
        billing_cycles?: number;
    }
    interface subscription_items_import_for_items_params {
        trial_end?: number;
    }
    interface subscription_items_import_for_items_params {
        service_period_days?: number;
    }
    interface subscription_items_import_for_items_params {
        charge_on_event?: string;
    }
    interface subscription_items_import_for_items_params {
        charge_once?: boolean;
    }
    interface subscription_items_import_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        item_type?: string;
    }
    interface discounts_import_for_items_params {
        apply_on?: string;
    }
    interface discounts_import_for_items_params {
        duration_type: string;
    }
    interface discounts_import_for_items_params {
        percentage?: number;
    }
    interface discounts_import_for_items_params {
        amount?: number;
    }
    interface discounts_import_for_items_params {
        period?: number;
    }
    interface discounts_import_for_items_params {
        period_unit?: string;
    }
    interface discounts_import_for_items_params {
        included_in_mrr?: boolean;
    }
    interface discounts_import_for_items_params {
        item_price_id?: string;
    }
    interface charged_items_import_for_items_params {
        item_price_id?: string;
    }
    interface charged_items_import_for_items_params {
        last_charged_at?: number;
    }
    interface item_tiers_import_for_items_params {
        item_price_id?: string;
    }
    interface item_tiers_import_for_items_params {
        starting_unit?: number;
    }
    interface item_tiers_import_for_items_params {
        ending_unit?: number;
    }
    interface item_tiers_import_for_items_params {
        price?: number;
    }
    interface item_tiers_import_for_items_params {
        starting_unit_in_decimal?: string;
    }
    interface item_tiers_import_for_items_params {
        ending_unit_in_decimal?: string;
    }
    interface item_tiers_import_for_items_params {
        price_in_decimal?: string;
    }
    interface item_tiers_import_for_items_params {
        pricing_type?: string;
    }
    interface item_tiers_import_for_items_params {
        package_size?: number;
    }
    interface coupons_import_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        coupon_id?: string;
    }
    interface coupons_import_for_items_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        apply_till?: number;
    }
    interface event_based_addons_cancel_params {
        id?: string;
    }
    interface event_based_addons_cancel_params {
        quantity?: number;
    }
    interface event_based_addons_cancel_params {
        unit_price?: number;
    }
    interface event_based_addons_cancel_params {
        service_period_in_days?: number;
    }
    interface subscription_items_cancel_for_items_params {
        item_price_id?: string;
    }
    interface subscription_items_cancel_for_items_params {
        quantity?: number;
    }
    interface subscription_items_cancel_for_items_params {
        quantity_in_decimal?: string;
    }
    interface subscription_items_cancel_for_items_params {
        unit_price?: number;
    }
    interface subscription_items_cancel_for_items_params {
        unit_price_in_decimal?: string;
    }
    interface subscription_items_cancel_for_items_params {
        service_period_days?: number;
    }
    interface payment_intent_resume_params {
        id?: string;
    }
    interface payment_intent_resume_params {
        gateway_account_id?: string;
    }
    interface payment_intent_resume_params {
        gw_token?: string;
    }
    interface payment_intent_resume_params {
        payment_method_type?: string;
    }
    interface payment_intent_resume_params {
        reference_id?: string;
    }
    interface payment_intent_resume_params {
        /**
         * @deprecated Please refer API docs to use other attributes
         */
        gw_payment_method_id?: string;
    }
    interface payment_intent_resume_params {
        additional_information?: any;
    }
}
